-- "Caesar's Gallic Wars" lua events file
-- v2018-04-05

print "Caesar's Gallic Wars"

--g note about local variables: lua supports (seemingly) a maximum of 200 local definitions
--g Code below is rather inefficient in that regard - if more defintions are needed, e.g. the unit aliases should be placed in a local defined table!
--g But for now ... :)


-- The `civ` library is written in C, and contains, generally, lower level functions to interact with the game.
-- It is always in scope.

-- The `civlua` library is written in Lua, and contains higher level functions built on the `civ` library.
local civlua = require "civlua"

-- The `functions` library contains general purpose functions.
local func = require "functions"

-- The `state` table represents the persistent state of the scenario, it is initialized here.
-- Keeping all state in a single table helps with serialization, see below.
-- The initial state can be empty for this scenario, since it's only used in calls to `justOnce`,
-- and all references to nonexistent keys evaluate to nil in lua.
local state = {}
	--g definition of variables - not strictly nescessary but allows an overlook here
	state.caesarKilled=state.caesarKilled or 0
	state.genavamTaken=state.genavamTaken or 0
	state.germanicInvasion=state.germanicInvasion or 0
	state.ariovistusDefeated=state.ariovistusDefeated or 0
	state.ambiorixUprising=state.ambiorixUprising or 0
	state.vercingetorixUprising=state.vercingetorixUprising or 0
	
	--g flags for whether or not recruitment is possible - not used currenty
	state.aeudiRecruitment=state.aeudiRecruitment or 1
	state.bataviRecruitment=state.bataviRecruitment or 1
	state.germanRecruitment=state.germanRecruitment or 1 
	
	state.winterSeason=state.winterSeason or 0 --g equivalent: Roman Flag 20 in events.txt
	state.belgaeMobilization=state.belgaeMobilization or 0 --g equivalent: Belgae Flag 20 in events.txt
	
	state.citiesTaken= state.citiesTaken or {belgae={}, others={} }
	
	state.legioDestroyed = state.legioDestroyed or {}
	

--g initialize random generator
math.randomseed(os.time())

---------------------------------------------------------------------------------------------------------------
--[[
Zone 1 196,76,280,76,280,124,196,124 controlled by Mediolanum (237,101)
 Zone 2 140,76,196,76,196,124,140,124 controlled by Massilia (156,120)
 Zone 3 86,94,140,94,140,124,86,124 controlled by Narbo (114,116)
 Zone 4 86,58,140,58,140,94,86,94 controlled by Gergovia (108,82)
 Zone 5 46,58,86,58,86,124,46,124 controlled by Namnetum (59,61)
 Zone 6 0,58,46,58,46,124,0,124 controlled by Lapurdum (38,104)
 Zone 7 0,28,52,28,52,58,0,58 controlled by Darioritum (43,53)
 Zone 8 52,28,102,28,102,58,52,58 controlled by Juliobona (96,38)
 Zone 9 0,0,102,0,102,28,0,28 controlled by Catuvellauni (99,3)
 Zone 10 102,0,140,0,140,58,102,58 controlled by Portus Itius (129,27)
 Zone 11 140,0,196,0,196,58,140,58 controlled by Aduatuca (181,31)
 Zone 12 196,0,280,0,280,34,196,34 controlled by Frisoni (198,8)
 Zone 13 196,34,280,34,280,76,196,76 controlled by Chatti (242,48)
 Zone 14 140,58,196,58,196,76,140,76 controlled by Bibracte (164,70)

 Zone 1 feeds to 2 (so if you control 1, you can also get ammo in 2)
 Zone 2 feeds to 3, 14
 Zone 3 feeds to 4
 Zone 4 feeds to 10, 5
 Zone 5 feeds to 4, 6, 8
 Zone 6 is a dead end
 Zone 7 is a dead end
 Zone 8 feeds to 7, 5, 10
 Zone 9 is a dead end
 Zone 10 feeds to 9, 8, 4
 Zone 11 feeds to 10
 Zone 12 is a dead end
 Zone 13 feeds to 12
 Zone 14 feeds to 11, 13

--]]

---------------------------------------------------------------------------------------------------------------
--g definitions header ----------------------------------------------------------------------------------------
--g Grishnach, 2018-02-21

local romanTribe = civ.getTribe(6)
local averniTribe = civ.getTribe(3)
local helvetiiTribe = civ.getTribe(1)
local germanicTribe = civ.getTribe(2)
local belgaeTribe = civ.getTribe(4)
local venetiiTribe = civ.getTribe(7)
local aquitaniiTribe = civ.getTribe(5)

---------------------------------------------------------------------------------------------------------------
--[[
0, Aquileia
1, Mediolanum
2, Narbo
3, Massilia
4, Genua
5, Bibracte
6, Genavam
7, The Alps
8, Vesontio
9, Segusiavi
10, Alesia
11, Avaricum
12, Vellaunodonum
13, Gergobina
14, Lutetia
15, The Hills
16, Gergovia
17, Uxellodonum
18, Lezoux
19, Noviodunum
20, Cenabum
21, Darioritum
22, Gesoscribate
23, Namnetum
24, Augustodorum
25, Condate
26, Juiliobona
27, The High Seas
28, Lapurdum
29, Burgidala
30, Sotiates
31, Tarusates
32, The Pyrenees
33, Limonum
34, Santonum
35, Aduatuca
36, Samarobriva
37, Portus Itius
38, Nemotecena
39, The Marshes
40, Frisoni
41, Chatti
42, Cherusci
43, Suebi
44, The Forests
45, Cantiaci
46, Atrebates
47, Catuvellauni
48, Stronghold
49, Fortress
50, Isle Fort
51, Bratuspantium
52, Bibrax
53, Aisne
54, Nervii
55, Aulerci
56, Cenomani

--]]

--g get id values from lua console: "for city in civ.iterateCities() do print(city.id, city.name) end"
local cityID = {
	["Bibracte"] = 5 
	,["Genavam"] = 6
	,["Samarobriva"] = 36
	,["Portus Itius"] = 37
	,["Nemotecena"] = 38
	,["Aduatuca"] = 35
	,["Juliobona"] = 26
	,["Augustodorum"] = 24
	,["Namnetum"] = 23
	,["Condata"] = 25
	,["Darioritum"] = 21
	,["Gesoscribate"] = 22
	,["Isle Fort"] = 50
	,["Stronghold"] = 48
	,["Fortress"] = 49
	,["Limonum"] = 33
	,["Santonum"] = 34
	,["Burgidala"] = 29
	,["Tarusates"] = 31
	,["Sotiates"] = 30
	,["Lapurdum"] = 28
	
	,["Aquileia"] = 0
	,["Mediolanum"] = 1
	,["Massilia"] = 3
	,["Narbo"] = 2
	,["Genua"] = 4
	
	,["Bratuspantium"] = 51
	,["Bibrax"] = 52
	,["Aisne"] = 53
	,["Nervii"] = 54 
	
	,["Lutetia"] = 14
	,["Gergovia"] = 16
	,["Gergobina"] = 13
	,["Cenabum"] = 20
	,["Noviodunum"] = 19
	,["Avaricum"] = 11
	,["Aulerci"] = 55
	,["Cenomani"] = 56	

}

local aquileia=civ.getCity(0)
local mediolanum=civ.getCity(1)
local massilia=civ.getCity(3)
local narbo=civ.getCity(2)
local genua=civ.getCity(4)
local bibracte=civ.getCity(5)

local bratuspantium=civ.getCity(51)
local bibrax=civ.getCity(52) 
local aisne=civ.getCity(53)  
local nervii=civ.getCity(54) 

local lutetia=civ.getCity(14) 
local gergovia=civ.getCity(16) 
local gergobina=civ.getCity(13) 
local cenabum=civ.getCity(20) 
local noviodunum=civ.getCity(19) 
local avaricum=civ.getCity(11) 

local sotiates=civ.getCity(30)
local tarusates=civ.getCity(31)
local santonum=civ.getCity(34)

local aulerci=civ.getCity(55)
local cenomani=civ.getCity(56)


---------------------------------------------------------------------------------------------------------------

--g rebuild: Create a table for each artillery unit
--g "displayText": if =nil then no text is displayed, if string ('example') then this is written into a popup box
--g "movementCost": now set up as a function - each press of "K" will create a munition (if terrain is ok) and then reduce remaining movement of the artillery unit. Typically this is a simple integer (full movement points), but in principle it could be any numeric value.
--					movement costs in winter - half the cost for land units so they can fire the same amount of munition.
	
local artilleryUnitTypes = {
	["Balearic slingers"] = { unitType=civ.getUnitType(69), munitionCreated=civ.getUnitType(103), allowedTerrain={0, 1, 2, 4, 5, 6, 11, 12, 14, 15, -128, -127, -126, -123, -114}, movementCostOfMunition=function (state) if state.winterSeason==1 then return 2 else return 4 end  end, displayText=nil }
	,["Cretan archers"] = { unitType=civ.getUnitType(65), munitionCreated=civ.getUnitType(102), allowedTerrain={0, 1, 2, 4, 5, 6, 11, 12, 14, 15, -128, -127, -126, -123, -114}, movementCostOfMunition=function (state) if state.winterSeason==1 then return 3 else return 6 end  end, displayText=nil }
	,["Onager"] = { unitType=civ.getUnitType(71), munitionCreated=civ.getUnitType(100), allowedTerrain={14}, movementCostOfMunition=function (state) if state.winterSeason==1 then return 4 else return 8 end  end, displayText=nil }
	,["Scorpio"] = { unitType=civ.getUnitType(70), munitionCreated=civ.getUnitType(101), allowedTerrain={0, 1, 2, 5, 11, 12, 14, 15, -128, -127, -126, -123, -114}, movementCostOfMunition=function (state) if state.winterSeason==1 then return 2 else return 4 end  end, displayText=nil }
	,["Trireme"] = { unitType=civ.getUnitType(34), munitionCreated=civ.getUnitType(41), allowedTerrain={10}, movementCostOfMunition=function (state) return 10 end, displayText=nil }
	,["Quinquereme"] = { unitType=civ.getUnitType(35), munitionCreated=civ.getUnitType(41), allowedTerrain={10}, movementCostOfMunition=function (state) return 4 end, displayText=nil }
	,["Mercenary Cavalry"] = { unitType=civ.getUnitType(105), munitionCreated=civ.getUnitType(106), allowedTerrain={0, 1, 2, 4, 5, 6, 11, 12, 14, 128}, movementCostOfMunition=function (state) if state.winterSeason==1 then return 1 else return 2 end  end, displayText=nil }
}
	
--g "conditionMet" ala TNO: define a function which takes the persistent state as a parameter, contains some check to be defined and returns true or false. If there should be no condition: always return true!
--g "movementCost": simlar to condition met, now set up as a function - each press of "K" will create a munition (if condition mentioned above is true) and then reduce remaining movement of the artillery unit. Typically this is a simple integer (full movement points), but in principle it could be any numeric value.
--g "displayText": if =nil then no text is displayed, if string ('example') then this is written into a popup box
local recruitmentUnitTypes = {
	["Centurion with Aedui"] = { unitType=civ.getUnitType(46), unitRecruited=civ.getUnitType(67), allowedTerrain={15}, movementCostOfRecruitment=function (state) if state.winterSeason==1 then return 2 else return 4 end end, moneyCostOfRecruitment=250, regionOfRecruitment_Xmin=140, regionOfRecruitment_Xmax=196, regionOfRecruitment_Ymin=58, regionOfRecruitment_Ymax=76, conditionMet=function (state) return true end, displayText="Aedui Allies of Rome join in the fight after being paid 250 denari!"  }
	,["Centurion with Batavi"] = { unitType=civ.getUnitType(46), unitRecruited=civ.getUnitType(13), allowedTerrain={15}, movementCostOfRecruitment=function (state) if state.winterSeason==1 then return 2 else return 4 end  end, moneyCostOfRecruitment=1000, regionOfRecruitment_Xmin=140, regionOfRecruitment_Xmax=196, regionOfRecruitment_Ymin=0, regionOfRecruitment_Ymax=57, conditionMet=function (state) return true end, displayText="A group of Batavian Horse are recruited for 1,000 denari! They are renowed for their ability to ford rivers (paradrop)." }
	,["Centurion with Germans"] = { unitType=civ.getUnitType(46), unitRecruited=civ.getUnitType(105), allowedTerrain={15}, movementCostOfRecruitment=function (state) if state.winterSeason==1 then return 2 else return 4 end  end, moneyCostOfRecruitment=1000, regionOfRecruitment_Xmin=224, regionOfRecruitment_Xmax=280, regionOfRecruitment_Ymin=40, regionOfRecruitment_Ymax=56, conditionMet=function (state) return true end, displayText="Deep in the forests of Germania, horsemen armed with javelins join the Roman cause after being paid 1,000 denari.  Though weak on attack, they are a ranged unit and can fire several javelins per turn (press 'k')." }
	,["Centurion with Belgae"] = { unitType=civ.getUnitType(46), unitRecruited=civ.getUnitType(108), allowedTerrain={15}, movementCostOfRecruitment=function (state) if state.winterSeason==1 then return 2 else return 4 end  end, moneyCostOfRecruitment=250, regionOfRecruitment_Xmin=102, regionOfRecruitment_Xmax=140, regionOfRecruitment_Ymin=24, regionOfRecruitment_Ymax=58, conditionMet=function (state) return true end, displayText="A group of Belgae mercenaries join the Roman cause after being paid 250 denari."}
	,["Centurion with Chariots"] = { unitType=civ.getUnitType(46), unitRecruited=civ.getUnitType(109), allowedTerrain={15}, movementCostOfRecruitment=function (state) if state.winterSeason==1 then return 2 else return 4 end  end, moneyCostOfRecruitment=1500, regionOfRecruitment_Xmin=104, regionOfRecruitment_Xmax=140, regionOfRecruitment_Ymin=0, regionOfRecruitment_Ymax=26, conditionMet=function (state) return true end, displayText="A group of Canti war chariots are convinced to join the Roman struggle after being paid 1,500 denari!"}
	,["Centurion with Lexovii"] = { unitType=civ.getUnitType(46), unitRecruited=civ.getUnitType(110), allowedTerrain={15}, movementCostOfRecruitment=function (state) if state.winterSeason==1 then return 2 else return 4 end  end, moneyCostOfRecruitment=250, regionOfRecruitment_Xmin=52, regionOfRecruitment_Xmax=102, regionOfRecruitment_Ymin=28, regionOfRecruitment_Ymax=58, conditionMet=function (state) return true end, displayText="A group of Lexovii mercenaries join the Roman cause after being paid 250 denari."}
	,["Centurion with Axemen"] = { unitType=civ.getUnitType(46), unitRecruited=civ.getUnitType(111), allowedTerrain={15}, movementCostOfRecruitment=function (state) if state.winterSeason==1 then return 2 else return 4 end  end, moneyCostOfRecruitment=750, regionOfRecruitment_Xmin=196, regionOfRecruitment_Xmax=280, regionOfRecruitment_Ymin=0, regionOfRecruitment_Ymax=34, conditionMet=function (state) return true end, displayText="A group of Germanic axemen mercenaries join the Roman cause after being paid 750 denari."}
	,["Centurion with Aquitani"] = { unitType=civ.getUnitType(46), unitRecruited=civ.getUnitType(112), allowedTerrain={15}, movementCostOfRecruitment=function (state) if state.winterSeason==1 then return 2 else return 4 end  end, moneyCostOfRecruitment=250, regionOfRecruitment_Xmin=46, regionOfRecruitment_Xmax=86, regionOfRecruitment_Ymin=58, regionOfRecruitment_Ymax=124, conditionMet=function (state) return true end, displayText="Disenchanted with their local leaders, and feeling their future lies with Rome, a group of Aquitani spearmen joins the Roman cause after being paid 250 denari."}
	,["Caesars administration"] = { unitType=civ.getUnitType(63), unitRecruited=nil, allowedTerrain={13}, movementCostOfRecruitment=function (state) if state.winterSeason==1 then return 2 else return 4 end  end, moneyCostOfRecruitment=-2000, regionOfRecruitment_Xmin=196, regionOfRecruitment_Xmax=280, regionOfRecruitment_Ymin=76, regionOfRecruitment_Ymax=124, conditionMet=function (state) return state.winterSeason==1 end, displayText="Caesar's glorious administration increases the wealth of the Roman Republic! 2,000 denari added to the Roman coffers! (You won't see these funds until you reselect Caesar's unit)" }
	,["Caesar recruits Scouts"] = { unitType=civ.getUnitType(63), unitRecruited=civ.getUnitType(107), allowedTerrain={15}, movementCostOfRecruitment=function (state) if state.winterSeason==1 then return 2 else return 4 end  end, moneyCostOfRecruitment=200, regionOfRecruitment_Xmin=0, regionOfRecruitment_Xmax=280, regionOfRecruitment_Ymin=0, regionOfRecruitment_Ymax=124, conditionMet=function (state) return true end, displayText="Caesar has recruited scouts to guide his way at the cost of 200 denari! Caesar can hire scouts in any village." }
	,["Centurion with Gallic Cav"] = { unitType=civ.getUnitType(46), unitRecruited=civ.getUnitType(68), allowedTerrain={15}, movementCostOfRecruitment=function (state) if state.winterSeason==1 then return 2 else return 4 end  end, moneyCostOfRecruitment=1000, regionOfRecruitment_Xmin=86, regionOfRecruitment_Xmax=140, regionOfRecruitment_Ymin=94, regionOfRecruitment_Ymax=124, conditionMet=function (state) return true end, displayText="A detachment of Gallic Cavalry has been procured for 1,000 denari.  Gallic cavalry know the land well and make excellent scouts." }
}
--g note: Caeasars administration does not create any unit (=nil) and does not subtract but rather add gold (-2000 -> so 2000 gold increase)

local unitTypesToBeDeletedEachTurn = { 41, 101, 102, 103 }
local unitTypesWhichCanBeDestroyedWithoutMovementReduction = { 41, 100, 101, 102, 103 }

	
--g definitons for "walls of alesia"

---------------------------------------------------------------------------------------------------------------

local wallsOfAlesiaTownfolkUnit=civ.getUnitType(86)
local wallsOfAlesiaText = "The Roman legions have chased Vercingetorix to Alesia.  Wary of assaulting the 80,000 within the city, but also knowing that another enormous Gallic relief army is marching to Vercingetorix's aid, Caesar orders a massive set of circumvallation fortifications facing Alesia, and a second, even greater set of contravallation fortifications facing away."
local wallsOfAlesiaTerrainType=5
local wallsOfAlesiaLocations={
 {168,56,0}
,{169,57,0}
,{171,55,0}
,{167,55,0}
,{170,56,0}
,{171,51,0}
,{172,54,0}
,{173,53,0}
,{172,52,0}
,{170,50,0}
,{169,49,0}
,{168,50,0}
,{167,51,0}
,{166,52,0}
,{167,53,0}
,{166,54,0}
}

local accessToBrittanyLocations={
 {49,47,0}
,{50,48,0}
,{51,47,0}
,{52,48,0}
,{53,47,0}
,{49,49,0}
,{50,50,0}
,{51,49,0}
,{52,50,0}
,{53,49,0}
,{49,51,0}
,{50,52,0}
,{51,51,0}
,{52,52,0}
,{53,51,0}
,{49,53,0}
,{50,54,0}
,{51,53,0}
,{52,54,0}
,{53,53,0}
,{49,55,0}
,{51,55,0}
,{53,55,0}
}


local vercingetorix=civ.getUnitType(45)
local arverniSwordsmen=civ.getUnitType(20)
local arverniArchers=civ.getUnitType(92)
local arverniCavalry=civ.getUnitType(23)
local arverniNobles=civ.getUnitType(22)
local arverniSpearmen=civ.getUnitType(21)

local helvetiiWarriors=civ.getUnitType(3)
local helvetiiNobles=civ.getUnitType(4)
local helvetiiMigrations=civ.getUnitType(88)
local helvetiiRefugees=civ.getUnitType(87)

local gallicTownfolk=civ.getUnitType(38)
local germanicVillagers=civ.getUnitType(85)
local germanicVillage=civ.getUnitType(7)

local romanSlaves=civ.getUnitType(39)

local celticSlingers=civ.getUnitType(18)
local celticOppidum=civ.getUnitType(47)

--g germanic units
local ariovistus=civ.getUnitType(44)

local germanSwordsmen=civ.getUnitType(94)
local germanCavalry=civ.getUnitType(95)
local germanNobles=civ.getUnitType(14)
local germanSkirmishers=civ.getUnitType(11)
local germanArchers=civ.getUnitType(12)

local eerieForest=civ.getUnitType(97)

local buildRhineBridge=civ.getUnitType(81)
local destroyBridge=civ.getUnitType(82)
local bridgeOverTheRhineTerrain=6
local destroyedBridgeTerrain=10

--g belgae units
local belgaeWarriors=civ.getUnitType(2)
local belgaeNobles=civ.getUnitType(24)

local nerviiWarriors=civ.getUnitType(115)

local ambiorix=civ.getUnitType(43)
local eburonesSpearmen=civ.getUnitType(25)
local eburonesSwordsmen=civ.getUnitType(26)
local eburonesNobles=civ.getUnitType(27)
local eburonesCavalry=civ.getUnitType(28)

local venetiSpearmen=civ.getUnitType(30)
local venetiSwordsmen=civ.getUnitType(31)
local venetiArchers=civ.getUnitType(32)
local venetiNobles=civ.getUnitType(33)
local lightShip=civ.getUnitType(36)
local heavyShip=civ.getUnitType(37)

--g britons
local druids=civ.getUnitType(42)
local holySite=civ.getUnitType(19)

--g roman units
local caesar=civ.getUnitType(63)
local labienus=civ.getUnitType(64)
local marcAntony=civ.getUnitType(114)

local legioIGermanica=civ.getUnitType(51)
local legioVAlaudae=civ.getUnitType(52)
local legioVIFerrata=civ.getUnitType(53)
local legioVIIClaudia=civ.getUnitType(54)
local legioVIIIAugusta=civ.getUnitType(55)
local legioIXHispana=civ.getUnitType(56)
local legioXFretensis=civ.getUnitType(57)
local legioXIFidelis=civ.getUnitType(58)
local legioXIIFulminata=civ.getUnitType(59)
local legioXIIIGemina=civ.getUnitType(60)
local legioXIVGMV=civ.getUnitType(61)
local legioXVApollinaris=civ.getUnitType(62)

local aeudiAllies=civ.getUnitType(67)
local gallicCav=civ.getUnitType(68)

local quinquereme=civ.getUnitType(35)
local munitions=civ.getUnitType(41)
local trireme=civ.getUnitType(34)
local massacre=civ.getUnitType(40)

local citizens=civ.getUnitType(50)
local alesiaProtectors=civ.getUnitType(113)

--aquitanii units
local tarusatesArmy=civ.getUnitType(77)
local sotiates=civ.getUnitType(75)

----------------------------------------------------------------------------------------------------------------------------------------

-- Various texts used in the scenario
local introText1 = "This scenario is dedicated to Tristan."
local introText2 = [[Special thanks are due to McMonkey, Tootall, Fairline, and above all, Grishnach, for their help, support, playtesting, and artistic contributions!
^
It goes beyond saying that this scenario would not have been possible without the amazing work done by "The Nameless One (TNO)" on the Test of Time Patch Project.  Thank you for all of your efforts!
^
Finally, I would be remiss if I did not mention my old friend, Agricola.  I was deeply saddened to return to this game only to find that you had passed on.  Your efforts made Germanicus on the Rhine what it was.  I sorely missed you in developing Caesar, and thought of you often while building it.]]

local introText3 = [[Thanks to TNO and Grishnach, this scenario utilizes lua events, which are very different from the macro language and allow greatly expanded possibilities. For example, this scenario features an area of recruitment and ranged attack units, among other innovations. 
^
Some effects (such as reduction of movement points or funds) will not be immediately obvious.  These effects will generally 'appear' after you reselect the unit in question.
^
PLEASE read the 'readme' so you can enjoy this scenario to the fullest.]]

local turnOneText0 = [[This scenario is dedicated to Tristan.]]

local turnOneText0A = [[Thanks to TNO and Grishnach, this scenario utilizes lua events, which are very different from the macro language and allow greatly expanded possibilities. For example, this scenario features an area of recruitment and ranged attack units, among other innovations. 
^
Some effects (such as reduction of movement points or funds) will not be immediately obvious.  These effects will generally 'appear' after you reselect the unit in question.
^
PLEASE read the 'readme' so you can enjoy this scenario to the fullest.]]

local turnOneText1 = [[The campaign against the Helvetii is but a means to an end for Caesar, and that end is simple: fortune and glory.  If he can conquer Gaul, he will be the greatest Roman to have ever lived.  Yet to conquer, he must first divide the tribes.
^
To the north are the Belgae: a fierce tribe of warriors unsoftened by trade goods which rarely reach them.  A campaign against them would be brutal, but better to ram a gladius in their belly than find a knife in your back.
^
In northwest Gaul you'll find the Veneti, a seafaring people who make their homes on island fortresses protected by the tides.  Romans have never been much for seafaring, but as in the Punic Wars, we can adapt.]]

local turnOneText2 = [[To the southwest are the Aquitani.  They are difficult to reach, but their lands are strategically important to Rome as they are often used to fuel rebellions in Hispania.  We should attempt to conquer them.
^
To the east are the Germans: a loose confederation of warlike tribes.  Their lands are poor and not much use to us, but crossing the Rhine would capture the Roman people's imagination.]]

local turnOneText3 = [[An even greater chance to intrigue the populace lies far to the northwest and across the seas: Britannia.  This ancient, mysterious island is rumored to be full of giants and tin.  Invading it would be a distraction from our main cause, but could have some benefit if we bring back the right trinkets.
^
Finally, in the center of Gaul lie the Arverni.  These tribes are powerful -- much too powerful to meddle with now, but their time will come...]]

local triumverateText= [[Caesar, Crassus, and Pompey reach agree that Crassus and Pompey will gain the consulship in 55 B.C., and Caesar's command in Gaul will extend a further 5 years, buying him needed time to enhance his prestige and accumulate wealth.]]

local crassusText= [[6 May 53 B.C. - Crassus' Parthian campaign has failed in a shocking defeat at Carrhae! Despite massive numerical superiority, seven legions are bested by the Parthian horsemen!  His corpse is brought before the Parthian king, who pours molten gold down its throat in contempt of Crassus' wealth.]] 

local returnLegioIText="In preparation for a war against Parthia to avenge Crassus, the Senate has demanded the return of the legion Pompey lent Caesar.  If Legio I exists, force march it to Italy where it must remain for the rest of the scenario.  If it does not exist, choose another."

local marcAntonyText= [[A dashing young general arrives at the front.  Marcus Antonius - better known today as 'Marc Antony,' - is renowned for his bravery. One day, gods willing, he will go on to sire a line that will produce one of Rome's greatest generals: Germanicus.]]

local winterText= [[The campaigning season draws to a close with the arrival of winter.  Caesar should return to Italy to handle the administrative tasks of his province.]]

local springText= [[Spring returns as Roman Legions leave their winter quarters and march towards the enemy.]]

local finalText="Caesar's governorship has ended.  The Senate has demanded that he disband his legions and return to Rome.  Knowing he may well be prosecuted for war crimes, he instead utters the phrase, 'alea iacta est', and marches on Rome with a single legion, but that is a tale for another time..."


local returnPompeyLegionPossibleText= [[The tides of civil war rise on the horizon.
^
Having allied himself with the aristocrat faction of the Senate, Pompey publicly demands that Caeasar returns the Legio I to fight in the Parthian War.
^
In a public display of obidience with the laws of the republic, Caesar acquiesces to the demand, knowing fully well that his veteran soldiers might soon be sent against him.]]

local returnPompeyLegionNotPossibleText= [[The tides of civil war rise on the horizon.
^
Having allied himself with the aristocrat faction of the Senate, Pompey publicly demands that Caeasar returns the Legio I to fight in the Parthian War.
^
However, due to the severe losses against the Gauls Caesar cannot do so - the public outcry is enormous!]]


----------------------------------------------------------------------------------------------------------------------------------------
--g Helper functions

--g set the terrain graphics - is called each turn and onLoad - if state.winterSeason==1 then the winter terrain is loaded, otherwise the summerTerrain
--g also: modify the movement points of all land units to half the summer value - hard coded, has to be updated if rules are changed!
local function setTerrainGraphicsAndRules(winterSeason)

	if winterSeason==1 then
		--g it is so cold!!!
		civ.ui.loadTerrain(0, 'wTerrain1.bmp', 'wTerrain2.bmp')

		if totpp.movementMultipliers then
			totpp.movementMultipliers.road=2
			totpp.movementMultipliers.railroad=4
		else
			civ.cosmic.roadMultiplier=2
		end
		local multiplier = civ.cosmic.roadMultiplier
		--if totpp.movementMultipliers then multiplier=totpp.movementMultipliers.aggregate end --g TNO said it is not needed - roadMultiplier always returns the aggregate :P
		
		civ.getUnitType(1).move = 4*multiplier --g Detachment in winter
		civ.getUnitType(2).move = 1*multiplier --g Belgae Warriors in winter
		civ.getUnitType(3).move = 1*multiplier --g Helvetii Warriors in winter
		civ.getUnitType(4).move = 1*multiplier --g Helvetii Nobles in winter
		civ.getUnitType(5).move = 1*multiplier --g Boii in winter
		civ.getUnitType(6).move = 1*multiplier --g Suebi in winter
		civ.getUnitType(9).move = 2*multiplier --g Siege Tower in winter
		civ.getUnitType(10).move = 1*multiplier --g Axemen in winter
		civ.getUnitType(11).move = 1*multiplier --g German Skirmishers in winter
		civ.getUnitType(12).move = 1*multiplier --g German Archers in winter
		civ.getUnitType(13).move = 4*multiplier --g Batavian Horse in winter
		civ.getUnitType(14).move = 1*multiplier --g German Nobles in winter
		civ.getUnitType(15).move = 1*multiplier --g British Skirm. in winter
		civ.getUnitType(16).move = 3*multiplier --g Chariot in winter
		civ.getUnitType(17).move = 1*multiplier --g British Swords in winter
		civ.getUnitType(18).move = 2*multiplier --g Celtic Slingers in winter
		civ.getUnitType(20).move = 1*multiplier --g Arverni Swordsmen in winter
		civ.getUnitType(21).move = 1*multiplier --g Arverni Spearmean in winter
		civ.getUnitType(22).move = 1*multiplier --g Arverni Nobles in winter
		civ.getUnitType(23).move = 3*multiplier --g Arverni Cavalry in winter
		civ.getUnitType(24).move = 1*multiplier --g Belgae Nobles in winter
		civ.getUnitType(25).move = 1*multiplier --g Eburones Spearmen in winter
		civ.getUnitType(26).move = 1*multiplier --g Eburones Swordsmen in winter
		civ.getUnitType(27).move = 1*multiplier --g Eburones Nobles in winter
		civ.getUnitType(28).move = 3*multiplier --g Eburones Cavalry in winter
		civ.getUnitType(29).move = 2*multiplier --g Naked Fanatics in winter
		civ.getUnitType(30).move = 1*multiplier --g Veneti Spearmen in winter
		civ.getUnitType(31).move = 1*multiplier --g Veneti Swordsmen in winter
		civ.getUnitType(32).move = 1*multiplier --g Veneti Archers in winter
		civ.getUnitType(33).move = 1*multiplier --g Veneti Nobles in winter
		civ.getUnitType(38).move = 1*multiplier --g Gallic Townfolk in winter
		civ.getUnitType(39).move = 2*multiplier --g Plunder in winter
		civ.getUnitType(42).move = 1*multiplier --g Druids in winter
		civ.getUnitType(43).move = 2*multiplier --g Ambiorix in winter
		civ.getUnitType(44).move = 2*multiplier --g Ariovistus in winter
		civ.getUnitType(45).move = 2*multiplier --g Vercingetorix in winter
		civ.getUnitType(46).move = 5*multiplier --g Centurion in winter
		civ.getUnitType(48).move = 3*multiplier --g Envoy in winter
		civ.getUnitType(49).move = 3*multiplier --g Senator in winter
		civ.getUnitType(51).move = 5*multiplier --g I 'Germanica' in winter
		civ.getUnitType(52).move = 5*multiplier --g V 'Alaudae' in winter
		civ.getUnitType(53).move = 5*multiplier --g VI 'Ferrata' in winter
		civ.getUnitType(54).move = 5*multiplier --g VII 'Claudia' in winter
		civ.getUnitType(55).move = 5*multiplier --g VIII 'Augusta' in winter
		civ.getUnitType(56).move = 5*multiplier --g IX 'Hispana' in winter
		civ.getUnitType(57).move = 5*multiplier --g X 'Fretensis' in winter
		civ.getUnitType(58).move = 5*multiplier --g XI 'Fidelis' in winter
		civ.getUnitType(59).move = 5*multiplier --g XII 'Fulminata' in winter
		civ.getUnitType(60).move = 5*multiplier --g XIII 'Gemina' in winter
		civ.getUnitType(61).move = 5*multiplier --g XIV 'G.M.V' in winter
		civ.getUnitType(62).move = 5*multiplier --g XV 'Apollinaris' in winter
		civ.getUnitType(63).move = 5*multiplier --g Julius Caesar in winter
		civ.getUnitType(64).move = 5*multiplier --g Titus Labienus in winter
		civ.getUnitType(65).move = 6*multiplier --g Cretan Archers in winter
		civ.getUnitType(66).move = 6*multiplier --g Roman Auxilia in winter
		civ.getUnitType(67).move = 6*multiplier --g Aeudi Auxilia in winter
		civ.getUnitType(68).move = 4*multiplier --g Gallic Cavalry in winter
		civ.getUnitType(69).move = 6*multiplier --g Balearic Slingers in winter
		civ.getUnitType(70).move = 4*multiplier --g Scorpio in winter
		civ.getUnitType(71).move = 4*multiplier --g Onager in winter
		civ.getUnitType(72).move = 8*multiplier --g Roman Cavalry in winter
		civ.getUnitType(75).move = 1*multiplier --g Sotiates Warriors in winter
		civ.getUnitType(76).move = 1*multiplier --g Vocates Spearmen in winter
		civ.getUnitType(77).move = 1*multiplier --g Tarusates in winter
		civ.getUnitType(78).move = 1*multiplier --g Chatti in winter
		civ.getUnitType(79).move = 1*multiplier --g Frisi in winter
		civ.getUnitType(80).move = 1*multiplier --g Cherusci in winter
		civ.getUnitType(87).move = 2*multiplier --g Helvetii Refugees in winter
		civ.getUnitType(88).move = 2*multiplier --g Migration in winter
		civ.getUnitType(89).move = 1*multiplier --g Aquitani Nobles in winter
		civ.getUnitType(92).move = 1*multiplier --g Arverni Archers in winter
		civ.getUnitType(93).move = 1*multiplier --g Aquitani Archers in winter
		civ.getUnitType(94).move = 1*multiplier --g German Swordsmen in winter
		civ.getUnitType(95).move = 3*multiplier --g German Cavalry in winter
		civ.getUnitType(104).move = 3*multiplier --g SAVE in winter
		civ.getUnitType(105).move = 4*multiplier --g Mercenary Cavalry in winter
		civ.getUnitType(107).move = 3*multiplier --g Scouts in winter
		civ.getUnitType(108).move = 6*multiplier --g Belgae Swordsmen in winter
		civ.getUnitType(109).move = 3*multiplier --g Chariot Mercenaries in winter
		civ.getUnitType(110).move = 6*multiplier --g Lexovii Spearmen in winter
		civ.getUnitType(111).move = 3*multiplier --g Germanic Axemen in winter
		civ.getUnitType(112).move = 6*multiplier --g Aquitani Spearmen in winter
		civ.getUnitType(114).move = 5*multiplier --g Marc Antony in winter
		civ.getUnitType(115).move = 1*multiplier --g Nervii Warriors in winter
		civ.getUnitType(116).move = 5*multiplier --jpp Gallic Legions in winter
	else
		--g it is so hot!
		civ.ui.loadTerrain(0, 'sTerrain1.bmp', 'sTerrain2.bmp')

		if totpp.movementMultipliers then
			totpp.movementMultipliers.road=4
			totpp.movementMultipliers.railroad=8
		else
			civ.cosmic.roadMultiplier=4
		end
		local multiplier = civ.cosmic.roadMultiplier
		--if totpp.movementMultipliers then multiplier=totpp.movementMultipliers.aggregate end --g TNO said it is not needed - roadMultiplier always returns the aggregate :P

		civ.getUnitType(1).move = 8*multiplier --g Detachment
		civ.getUnitType(2).move = 2*multiplier --g Belgae Warriors
		civ.getUnitType(3).move = 2*multiplier --g Helvetii Warriors
		civ.getUnitType(4).move = 2*multiplier --g Helvetii Nobles
		civ.getUnitType(5).move = 2*multiplier --g Boii
		civ.getUnitType(6).move = 2*multiplier --g Suebi
		civ.getUnitType(9).move = 4*multiplier --g Siege Tower
		civ.getUnitType(10).move = 2*multiplier --g Axemen
		civ.getUnitType(11).move = 2*multiplier --g German Skirmishers
		civ.getUnitType(12).move = 2*multiplier --g German Archers
		civ.getUnitType(13).move = 8*multiplier --g Batavian Horse
		civ.getUnitType(14).move = 2*multiplier --g German Nobles
		civ.getUnitType(15).move = 2*multiplier --g British Skirm.
		civ.getUnitType(16).move = 6*multiplier --g Chariot
		civ.getUnitType(17).move = 2*multiplier --g British Swords
		civ.getUnitType(18).move = 4*multiplier --g Celtic Slingers
		civ.getUnitType(20).move = 2*multiplier --g Arverni Swordsmen
		civ.getUnitType(21).move = 2*multiplier --g Arverni Spearmean
		civ.getUnitType(22).move = 2*multiplier --g Arverni Nobles
		civ.getUnitType(23).move = 6*multiplier --g Arverni Cavalry
		civ.getUnitType(24).move = 2*multiplier --g Belgae Nobles
		civ.getUnitType(25).move = 2*multiplier --g Eburones Spearmen
		civ.getUnitType(26).move = 2*multiplier --g Eburones Swordsmen
		civ.getUnitType(27).move = 2*multiplier --g Eburones Nobles
		civ.getUnitType(28).move = 6*multiplier --g Eburones Cavalry
		civ.getUnitType(29).move = 3*multiplier --g Naked Fanatics
		civ.getUnitType(30).move = 2*multiplier --g Veneti Spearmen
		civ.getUnitType(31).move = 2*multiplier --g Veneti Swordsmen
		civ.getUnitType(32).move = 2*multiplier --g Veneti Archers
		civ.getUnitType(33).move = 2*multiplier --g Veneti Nobles
		civ.getUnitType(38).move = 2*multiplier --g Gallic Townfolk
		civ.getUnitType(39).move = 3*multiplier --g Plunder
		civ.getUnitType(42).move = 2*multiplier --g Druids
		civ.getUnitType(43).move = 4*multiplier --g Ambiorix
		civ.getUnitType(44).move = 4*multiplier --g Ariovistus
		civ.getUnitType(45).move = 4*multiplier --g Vercingetorix
		civ.getUnitType(46).move = 10*multiplier --g Centurion
		civ.getUnitType(48).move = 6*multiplier --g Envoy
		civ.getUnitType(49).move = 6*multiplier --g Senator
		civ.getUnitType(51).move = 10*multiplier --g I 'Germanica'
		civ.getUnitType(52).move = 10*multiplier --g V 'Alaudae'
		civ.getUnitType(53).move = 10*multiplier --g VI 'Ferrata'
		civ.getUnitType(54).move = 10*multiplier --g VII 'Claudia'
		civ.getUnitType(55).move = 10*multiplier --g VIII 'Augusta'
		civ.getUnitType(56).move = 10*multiplier --g IX 'Hispana'
		civ.getUnitType(57).move = 10*multiplier --g X 'Fretensis'
		civ.getUnitType(58).move = 10*multiplier --g XI 'Fidelis'
		civ.getUnitType(59).move = 10*multiplier --g XII 'Fulminata'
		civ.getUnitType(60).move = 10*multiplier --g XIII 'Gemina'
		civ.getUnitType(61).move = 10*multiplier --g XIV 'G.M.V'
		civ.getUnitType(62).move = 10*multiplier --g XV 'Apollinaris'
		civ.getUnitType(63).move = 10*multiplier --g Julius Caesar
		civ.getUnitType(64).move = 10*multiplier --g Titus Labienus
		civ.getUnitType(65).move = 12*multiplier --g Cretan Archers
		civ.getUnitType(66).move = 12*multiplier --g Roman Auxilia
		civ.getUnitType(67).move = 12*multiplier --g Aeudi Auxilia
		civ.getUnitType(68).move = 8*multiplier --g Gallic Cavalry
		civ.getUnitType(69).move = 12*multiplier --g Balearic Slingers
		civ.getUnitType(70).move = 8*multiplier --g Scorpio
		civ.getUnitType(71).move = 8*multiplier --g Onager
		civ.getUnitType(72).move = 16*multiplier --g Roman Cavalry
		civ.getUnitType(75).move = 2*multiplier --g Sotiates Warriors
		civ.getUnitType(76).move = 2*multiplier --g Vocates Spearmen
		civ.getUnitType(77).move = 2*multiplier --g Tarusates
		civ.getUnitType(78).move = 2*multiplier --g Chatti
		civ.getUnitType(79).move = 2*multiplier --g Frisi
		civ.getUnitType(80).move = 2*multiplier --g Cherusci
		civ.getUnitType(87).move = 4*multiplier --g Helvetii Refugees
		civ.getUnitType(88).move = 4*multiplier --g Migration
		civ.getUnitType(89).move = 2*multiplier --g Aquitani Nobles
		civ.getUnitType(92).move = 2*multiplier --g Arverni Archers
		civ.getUnitType(93).move = 2*multiplier --g Aquitani Archers
		civ.getUnitType(94).move = 2*multiplier --g German Swordsmen
		civ.getUnitType(95).move = 6*multiplier --g German Cavalry
		civ.getUnitType(104).move = 6*multiplier --g SAVE
		civ.getUnitType(105).move = 8*multiplier --g Mercenary Cavalry
		civ.getUnitType(107).move = 6*multiplier --g Scouts
		civ.getUnitType(108).move = 12*multiplier --g Belgae Swordsmen
		civ.getUnitType(109).move = 6*multiplier --g Chariot Mercenaries
		civ.getUnitType(110).move = 12*multiplier --g Lexovii Spearmen
		civ.getUnitType(111).move = 6*multiplier --g Germanic Axemen
		civ.getUnitType(112).move = 12*multiplier --g Aquitani Spearmen
		civ.getUnitType(114).move = 10*multiplier --g Marc Antony
		civ.getUnitType(115).move = 2*multiplier --g Nervii Warriors
		civ.getUnitType(116).move = 10*multiplier --jpp Gallic Legions in summer
	end

end

----------------------------------------------------------------------------------------------------------------------------------------

-- Our local 'justOnce' function, so it uses our state.
local justOnce = function (key, f) civlua.justOnce(civlua.property(state, key), f) end

local negate = function (f) return function (x) return not f(x) end end

--g local function: Get length of table / number of elements
local function tablelength(T)
  local count = 0
  for _ in pairs(T) do count = count + 1 end
  return count
end

function round(val, decimal)
  local exp = decimal and 10^decimal or 1
  return math.ceil(val * exp - 0.5) / exp
end

---------------------------------------------------------------------------------------------------------------

--g First subjugation of Belgica
local function checkBelgicaFirstSubjugation()
	--local belgicaSubdued = state.samarobrivaTaken + state.portusItiusTaken + state.nemotecenaTaken + state.aduatucaTaken + state.bibraxTaken + 
	--state.bratuspantiumTaken + state.aisneTaken + state.nerviiTaken
	
	local belgicaSubdued=0
	--g loop over the cities in the table belgae only
	for city,state in pairs(state.citiesTaken.belgae) do
		--g if the entry in the array is "==true", then incement the counter by one
		if state then belgicaSubdued=belgicaSubdued+1 end
	end
	
	return belgicaSubdued
end

--g Check further events like agression by Venetii - count all cities subjugated
local function conqueredCities()
	--local venetiiAgression= state.samarobrivaTaken + state.portusItiusTaken + state.nemotecenaTaken + state.aduatucaTaken
	--venetiiAgression= venetiiAgression + state.juliobonaTaken + state.augustodorumTaken + state.namnetumTaken + state.condataTaken + state.darioritumTaken + state.gesoscribateTaken
	--venetiiAgression= venetiiAgression + state.isleFortTaken + state.strongholdTaken + state.fortressTaken
	--venetiiAgression= venetiiAgression + state.limonumTaken + state.santonumTaken + state.burgidalaTaken + state.tarusatesTaken + state.sotiatesTaken
	--venetiiAgression= venetiiAgression + state.lapurdumTaken + state.bibraxTaken + state.bratuspantiumTaken + state.aisneTaken + state.nerviiTaken  --g not sure if this should be in?
	
	local gaulSubdued=0
	--g loop over the cities in all the tables (belgae, venetii, aquitanii, ...)
	for _,tab in pairs(state.citiesTaken) do
		for city,state in pairs(tab) do
			if state then gaulSubdued=gaulSubdued+1 end
		end
	end

	--return venetiiAgression
	return gaulSubdued
end

--g get number of destroyed Legions
local function destroyedLegions()
	--local countMassacres = state.legio01Destroyed  + state.legio05Destroyed	+ state.legio06Destroyed + state.legio07Destroyed + state.legio08Destroyed + state.legio09Destroyed
	--countMassacres = countMassacres + state.legio10Destroyed + state.legio11Destroyed + state.legio12Destroyed + state.legio13Destroyed + state.legio14Destroyed + state.legio15Destroyed
	
	local countMassacres=0
	--g loop over all destroyed legions
	for legion,state in pairs(state.legioDestroyed) do
		--g if the entry in the array is "==true", then incement the counter by one
		if state then countMassacres=countMassacres+1 end
	end
	
	return countMassacres
end
---------------------------------------------------------------------------------------------------------------
--+ state.cenomaniTaken + state.aulerciTaken (did not work in line 723 above).



--g "Key Pressed" execution
--g Grishnach, 2018-02-21

--[[
210	ESC
176	F1
177	F2
178	F3
179	F4
180	F5
181	F6
182	F7
183	F8
184	F9
--- F10 is not being caught?
186 F11
187 F12
214	Back

ASCII Table
Dec  = Decimal Value
Char = Character

'5' has the int value 53
if we write '5'-'0' it evaluates to 53-48, or the int 5
if we write char c = 'B'+32; then c stores 'b'


Dec  Char                           Dec  Char     Dec  Char     Dec  Char
---------                           ---------     ---------     ----------
  0  NUL (null)                      32  SPACE     64  @         96  `
  1  SOH (start of heading)          33  !         65  A         97  a
  2  STX (start of text)             34  "         66  B         98  b
  3  ETX (end of text)               35  #         67  C         99  c
  4  EOT (end of transmission)       36  $         68  D        100  d
  5  ENQ (enquiry)                   37  %         69  E        101  e
  6  ACK (acknowledge)               38  &         70  F        102  f
  7  BEL (bell)                      39  '         71  G        103  g
  8  BS  (backspace)                 40  (         72  H        104  h
  9  TAB (horizontal tab)            41  )         73  I        105  i
 10  LF  (NL line feed, new line)    42  *         74  J        106  j
 11  VT  (vertical tab)              43  +         75  K        107  k
 12  FF  (NP form feed, new page)    44  ,         76  L        108  l
 13  CR  (carriage return)           45  -         77  M        109  m
 14  SO  (shift out)                 46  .         78  N        110  n
 15  SI  (shift in)                  47  /         79  O        111  o
 16  DLE (data link escape)          48  0         80  P        112  p
 17  DC1 (device control 1)          49  1         81  Q        113  q
 18  DC2 (device control 2)          50  2         82  R        114  r
 19  DC3 (device control 3)          51  3         83  S        115  s
 20  DC4 (device control 4)          52  4         84  T        116  t
 21  NAK (negative acknowledge)      53  5         85  U        117  u
 22  SYN (synchronous idle)          54  6         86  V        118  v
 23  ETB (end of trans. block)       55  7         87  W        119  w
 24  CAN (cancel)                    56  8         88  X        120  x
 25  EM  (end of medium)             57  9         89  Y        121  y
 26  SUB (substitute)                58  :         90  Z        122  z
 27  ESC (escape)                    59  ;         91  [        123  {
 28  FS  (file separator)            60  <         92  \        124  |
 29  GS  (group separator)           61  =         93  ]        125  }
 30  RS  (record separator)          62  >         94  ^        126  ~
 31  US  (unit separator)            63  ?         95  _        127  DEL



--]]


local keyPressed = function(keyID)
	--civ.ui.text(func.splitlines(tostring(keyID)))
	--civ.ui.text(func.splitlines(tostring(currentUnit.location.terrainType)))

	--g get the movement multiplier for the calculation of the movement reductions of artillery munition and recruitment etc
	--g work around to get the same amount of munitions etc in the winter turns (where movement is halved from eg 4 to 2 movement points) - halve the multiplier in winter :)
	local multiplier = civ.cosmic.roadMultiplier
	--if state.winterSeason==1 then multiplier=round(multiplier/2, 0) end --g: Adaptation of the movement cost property: Is now a function returning different movement costs in winter - half the cost for land units so they can fire the same amount of munition.
	
		
	--g if key "V" - debugging, toggle winter season
	--if keyID==86 then
		--if state.winterSeason==1 then state.winterSeason=0 else state.winterSeason=1 end
	--	print("winter season: ", tostring(state.winterSeason))
--	end
	
	--g if key "K" - debugging
	if keyID==75 then
		print("Check belgica subjugation: ", tostring(checkBelgicaFirstSubjugation()))
		print("Check total number cities conquered: ", tostring(conqueredCities()))
	end
	
	--g If key "K" - check for unit type to create munitions
	if keyID==75 and civ.getActiveUnit() ~= nil then

		--civ.ui.text(func.splitlines(tostring(keyID)))
		local currentUnit = civ.getActiveUnit()
		local currentTileCoordinates = { {currentUnit.location.x, currentUnit.location.y, currentUnit.location.z } }
		
		--g loop over all artilleryUnit Types
		for ___, artilleryUnit in pairs(artilleryUnitTypes) do
			
			if artilleryUnit.unitType.id == currentUnit.type.id then
				correctTerrain=0
				for _, allowedTerrain in pairs(artilleryUnit.allowedTerrain) do
					if currentUnit.location.terrainType==allowedTerrain then
						correctTerrain=1
					end
				end
				
				if correctTerrain==1 then
					civlua.createUnit(artilleryUnit.munitionCreated, currentUnit.owner, currentTileCoordinates, {randomize=false, veteran=false})
					--g after creation: reduce movement points of artillery unit, but do not go beyond the max movement points of the unit type
					local newSpent=currentUnit.moveSpent+artilleryUnit.movementCostOfMunition(state)*multiplier
					if newSpent>currentUnit.type.move then newSpent=currentUnit.type.move end
					currentUnit.moveSpent=newSpent
					
					if artilleryUnit.displayText ~= nil then
						civ.ui.text(func.splitlines(tostring(artilleryUnit.displayText)))
					end
					
				end
			end
		end

		--g loop over all recruitmentUnit Types
		for ____, recruitmentUnit in pairs(recruitmentUnitTypes) do
			
			if recruitmentUnit.unitType.id == currentUnit.type.id then
				local correctTerrain=0
				for _, allowedTerrain in pairs(recruitmentUnit.allowedTerrain) do
					if currentUnit.location.terrainType==allowedTerrain then
						--civ.ui.text(func.splitlines(tostring(allowedTerrain)))
						correctTerrain=1
					end
				end
				
				local correctRegion=0
				if recruitmentUnit.regionOfRecruitment_Xmin<=currentUnit.location.x and recruitmentUnit.regionOfRecruitment_Xmax>=currentUnit.location.x and recruitmentUnit.regionOfRecruitment_Ymin<=currentUnit.location.y and recruitmentUnit.regionOfRecruitment_Ymax>=currentUnit.location.y then
					correctRegion=1
				end
				
				local enoughMoney=1
				if currentUnit.owner.money<recruitmentUnit.moneyCostOfRecruitment then enoughMoney=0 end
				
				if correctTerrain==1 and correctRegion==1 and enoughMoney==1 and recruitmentUnit.conditionMet(state) then
					--g check if the recruitment Type has some info recruit at all
					if recruitmentUnit.unitRecruited ~= nil then
						civlua.createUnit(recruitmentUnit.unitRecruited, currentUnit.owner, currentTileCoordinates, {randomize=false, veteran=false})
					end
					
					--g perform the money operation in any case though - allows implementation of "earn money" events
					--g after creation: reduce movement points of artillery unit, but do not go beyond the max movement points of the unit type
					local newSpent=currentUnit.moveSpent+recruitmentUnit.movementCostOfRecruitment(state)*multiplier
					if newSpent>currentUnit.type.move then newSpent=currentUnit.type.move end
					currentUnit.moveSpent=newSpent
					
					currentUnit.owner.money=currentUnit.owner.money-recruitmentUnit.moneyCostOfRecruitment
					
					if recruitmentUnit.displayText ~= nil then
						civ.ui.text(func.splitlines(tostring(recruitmentUnit.displayText)))
					end
				end
			end
		end

	end


end

civ.scen.onKeyPress(keyPressed)
----------------------------------------------------------------------------------------------------------------------------------------
--g Triggers

-- The `onTurn` function runs its argument every turn, with the turn number passed as `turn`.
civ.scen.onTurn(function (turn)

	--g Destruction of artillery munition etc - certain unit types are scanned for and removed immediately; iterate all units and check ID against unitTypesToBeDeletedEachTurn
	for unit in civ.iterateUnits() do
	
		for _, typeToBeDeleted in pairs(unitTypesToBeDeletedEachTurn) do
			if unit.type.id==typeToBeDeleted then
				civ.deleteUnit(unit)
			end
		end
		
	end

--	civ.ui.text(func.splitlines( civ.getToTDir() ))
--[[  
infile = io.open("temp.csv", "r")
instr = infile:read("*a")
infile:close()

outfile = io.open("log.csv", "w")
outfile:write(instr)
outfile:close()
--]]

	-- Show the intro text on the first turn. I'm omitting `justOnce` since it won't be turn 1 more than once anyway.

	
	if turn == 1 then
		civ.playSound('overture.wav')
		civ.ui.text(func.splitlines(turnOneText0))
		civ.ui.text(func.splitlines(turnOneText1))
		civ.ui.text(func.splitlines(turnOneText2))
		civ.ui.text(func.splitlines(turnOneText3))
		civ.ui.text(func.splitlines(turnOneText0A))
	end
  
	if turn==8 or turn==20 or turn==32 or turn==44 or turn==56 or turn==68 or turn==80 or turn==92 or turn==104 then
		state.winterSeason=1
		civ.ui.text(func.splitlines(winterText))
	end
 	if turn==12 or turn==24 or turn==36 or turn==48 or turn==60 or turn==72 or turn==84 or turn==96 then
		state.winterSeason=0
		civ.ui.text(func.splitlines(springText))
	end
	setTerrainGraphicsAndRules(state.winterSeason)
	
	if turn == 26 then
		civ.ui.text(func.splitlines(triumverateText))
	end 
	
	if turn == 47 then
		civ.ui.text(func.splitlines(marcAntonyText))
		civlua.createUnit(marcAntony, romanTribe, {{156,120,0}}, {randomize=false, veteran=false})
	end
	
	if turn == 62 then
		civ.ui.text(func.splitlines(crassusText))
	end 
	
--	if turn==92 then
--		civ.ui.text(func.splitlines(returnLegioIText))
--	end
	if turn==96 and romanTribe:hasTech(civ.getTech(3)) then
		--g Pompey demands his legion back!
		if state.legioDestroyed.legio01 then
			--g the Legio I has been destroyed and cannot be destroyed ...
			civ.ui.text(func.splitlines(returnPompeyLegionNotPossibleText))
			--g and something else bad happens??
		else
			--g Legio I still exists, and is returned with honors!
			civ.ui.text(func.splitlines(returnPompeyLegionPossibleText))
			for u in civ.iterateUnits() do
				if u.id==legioIGermanica.id then
					civ.deleteUnit(u)
				end
			end
 
		end
 
	end --g Return of Pompeys Legion
	
	if turn==106 then
		civ.playSound('Rubicon.wav')
		civ.ui.text(func.splitlines(finalText))
	end
	
 
  
	--g helvetii migration events - spawn units each turn as long as flag state.genavamTaken ~= 1
	if state.genavamTaken ~= 1 then
	
		--g Create new units
		civlua.createUnit(helvetiiNobles, helvetiiTribe, {{160,92,0},{158,94,0},{156,92,0}}, {count=2, randomize=true, veteran=true})
		civlua.createUnit(helvetiiWarriors, helvetiiTribe, {{158,94,0},{156,92,0},{158,90,0}}, {count=6, randomize=true, veteran=true})
		civlua.createUnit(helvetiiMigrations, helvetiiTribe, {{156,92,0},{158,90,0},{159,91,0}}, {count=1, randomize=true, veteran=true})
		civlua.createUnit(helvetiiRefugees, helvetiiTribe, {{158,90,0},{159,91,0},{160,92,0}}, {count=1, randomize=true, veteran=true})

		--g and then MoveUnit command for all in map rect 153,79,175,79,175,97,153,97 to move to 164,70
		for u in civ.iterateUnits() do
			if u.owner.id==helvetiiTribe.id and u.location.x >= 153 and u.location.x <= 175 and u.location.y >= 79 and u.location.y <= 97 then
				u.gotoTile = civ.getTile(169, 53, 0)
			end
		end
		
	end;
  
	--g germanic invasion events - spawn units each turn as long as flag state.germanicInvasion == 1 - from conquest of Genevam until defeat of eerie forest
	if state.germanicInvasion == 1 then
	
		--g Create new units
		civlua.createUnit(germanSkirmishers, germanicTribe, {{185,55,0},{187,59,0},{180,64,0},{200,68,0}}, {count=2, randomize=true, veteran=true})
		civlua.createUnit(germanSwordsmen, germanicTribe, {{200,68,0},{180,64,0},{185,55,0},{187,59,0}}, {count=2, randomize=true, veteran=true})

		--g loop over all units, check if they are Barbarian units within the rectangle 175,67,191,67,191,81,175,81, and if so, give gotoTile command
		for u in civ.iterateUnits() do
			if u.owner.id==germanicTribe.id and u.location.x >= 175 and u.location.x <= 191 and u.location.y >= 67 and u.location.y <= 81 then
				u.gotoTile = civ.getTile(164,70, 0)
			end
		end
		
	end --end of germanic invasion spawn
	
	
--g Belgae campaign events - spawn units each turn as long as flag state.belgaeMobilization == 1 - from attack of romans to conquest of X cities in Belgica
 	if state.belgaeMobilization == 1 then
		civlua.createUnit(belgaeWarriors, belgaeTribe, {{132,34,0},{132,38,0},{130,40,0},{127,37,0}}, {count=1, randomize=false, veteran=true})
		civlua.createUnit(belgaeWarriors, belgaeTribe, {{143,41,0},{146,34,0},{146,40,0}}, {count=1, randomize=true, veteran=false})
		civlua.createUnit(belgaeNobles, belgaeTribe, {{154,32,0},{153,29,0},{158,54,0}}, {count=1, randomize=true, veteran=true})
		
		civlua.createUnit(belgaeWarriors, belgaeTribe, {{174,28,0},{176,28,0},{181,27,0},{184,30,0}}, {count=1, randomize=true, veteran=false})
		civlua.createUnit(belgaeWarriors, belgaeTribe, {{174,28,0},{176,28,0},{181,27,0},{184,30,0}}, {count=1, randomize=true, veteran=true})
		civlua.createUnit(belgaeNobles, belgaeTribe, {{174,28,0},{176,28,0},{181,27,0},{184,30,0}}, {count=1, randomize=true, veteran=true})
		
		civlua.createUnit(belgaeWarriors, belgaeTribe, {{126,36,0},{129,33,0},{132,36,0},{129,41,0}}, {count=1, randomize=true, veteran=false})
		civlua.createUnit(belgaeWarriors, belgaeTribe, {{126,36,0},{129,33,0},{132,36,0},{129,41,0}}, {count=1, randomize=true, veteran=false})
		civlua.createUnit(belgaeNobles, belgaeTribe, {{126,36,0},{129,33,0},{132,36,0},{129,41,0}}, {count=1, randomize=true, veteran=true})
	
		--g loop over all units, check if they are Barbarian units within the rectangle 119,25,157,24,157,51,119,51, and if so, give gotoTile command
		for u in civ.iterateUnits() do
			if u.owner.id==belgaeTribe.id and u.location.x >= 124 and u.location.x <= 138 and u.location.y >= 26 and u.location.y <= 40 then
				u.gotoTile = civ.getTile(129,37, 0)
			end
			if u.owner.id==belgaeTribe.id and u.location.x >= 140 and u.location.x <= 160 and u.location.y >= 28 and u.location.y <= 50 then
				u.gotoTile = civ.getTile(144,38, 0)
			end
			if u.owner.id==belgaeTribe.id and u.location.x >= 169 and u.location.x <=185 and u.location.y >= 25 and u.location.y <= 35 then
				u.gotoTile = civ.getTile(181,31, 0)
			end
		end

	end -- end of belgae spawns
	
	if checkBelgicaFirstSubjugation() >= 5 then
		justOnce("BelgicaFirstSubjugation", function () 
			civ.ui.text(func.splitlines("Having captured several cities and winning several battles, Caesar largely subdues the tribes Belgica.  There will be a few warriors who refuse to submit, but once they are beaten, the region should be peaceful.  For now..."))
			state.belgaeMobilization = 2
		end)
	end
	
	local numberOfConqueredCities = conqueredCities()
	
	--g Venetii campaign - aggression starts once more than 3 of 18 cities have been conquered by Rome
	if numberOfConqueredCities >= 3 then
		justOnce("VenetiiAgression", function ()
			civ.ui.text(func.splitlines("Alarmed at the growing Roman presence near their lands, and concerned that Roman interests in Britainnia will conflict with their trade rights, the Venetii launch a rebellion!"))
			civ.makeAggression(venetiiTribe, romanTribe)
		end)
	end
	
	
	--g Ambiorix campaign
	if numberOfConqueredCities >= 10 and state.winterSeason==1 then
		justOnce("AmbiorixAgression", function ()
			civ.ui.text(func.splitlines("A drought has disrupted the Roman grain supply, forcing Caesar to once again demand supplies from the tribes of Belgica.  Having enough of this, the leader of the Eburones, Ambiorix, leads a massive revolt against the Roman invaders."))
			civlua.createUnit(ambiorix, belgaeTribe, {{170,32,0},{167,31,0},{161,29,0},{148,30,0},{145,31,0},{147,35,0}}, {count=1, randomize=true, veteran=true})
			state.ambiorixUprising=1
		end)
	end
	
	if state.ambiorixUprising == 1 then
	
		--g Create new units
		civlua.createUnit(eburonesSpearmen, belgaeTribe, {{170,32,0},{167,31,0},{161,29,0},{148,30,0},{145,31,0},{147,35,0}}, {count=6, randomize=true, veteran=true})
		civlua.createUnit(eburonesSwordsmen, belgaeTribe, {{170,32,0},{167,31,0},{161,29,0},{148,30,0},{145,31,0},{147,35,0}}, {count=6, randomize=true, veteran=true})
		civlua.createUnit(eburonesCavalry, belgaeTribe, {{170,32,0},{167,31,0},{161,29,0},{148,30,0},{145,31,0},{147,35,0}}, {count=4, randomize=true, veteran=true})
		civlua.createUnit(eburonesNobles, belgaeTribe, {{158,28,0},{155,27,0},{153,25,0},{145,31,0},{147,35,0}}, {count=2, randomize=true, veteran=true})

		civlua.createUnit(eburonesNobles, belgaeTribe, {{145,43,0},{142,44,0},{147,45,0},{144,36,0},{141,37,0}}, {count=2, randomize=true, veteran=true})
		civlua.createUnit(eburonesSpearmen, belgaeTribe, {{145,43,0},{142,44,0},{147,45,0},{144,36,0},{141,37,0}}, {count=6, randomize=true, veteran=true})
		civlua.createUnit(eburonesSwordsmen, belgaeTribe, {{145,43,0},{142,44,0},{147,45,0},{144,36,0},{141,37,0}}, {count=6, randomize=true, veteran=true})
		civlua.createUnit(eburonesCavalry, belgaeTribe, {{145,43,0},{142,44,0},{147,45,0},{144,36,0},{141,37,0}}, {count=4, randomize=true, veteran=true})

		civlua.createUnit(eburonesSwordsmen, belgaeTribe, {{127,39,0},{127,35,0},{130,32,0},{133,31,0}}, {count=6, randomize=true, veteran=true})
		civlua.createUnit(eburonesCavalry, belgaeTribe, {{127,39,0},{127,35,0},{130,32,0},{133,31,0}}, {count=4, randomize=true, veteran=true})
		civlua.createUnit(eburonesSpearmen, belgaeTribe, {{127,39,0},{127,35,0},{130,32,0},{133,31,0}}, {count=6, randomize=true, veteran=true})
		civlua.createUnit(eburonesNobles, belgaeTribe, {{127,39,0},{127,35,0},{130,32,0},{133,31,0}}, {count=2, randomize=true, veteran=true})
		
		civlua.createUnit(eburonesNobles, belgaeTribe, {{183,29,0},{180,32,0},{180,30,0},{180,34,0}}, {count=2, randomize=true, veteran=true})
		civlua.createUnit(eburonesSwordsmen, belgaeTribe, {{183,29,0},{180,32,0},{180,30,0},{180,34,0}}, {count=6, randomize=true, veteran=true})
		civlua.createUnit(eburonesSpearmen, belgaeTribe, {{183,29,0},{180,32,0},{180,30,0},{180,34,0}}, {count=6, randomize=true, veteran=true})
		civlua.createUnit(eburonesCavalry, belgaeTribe, {{183,29,0},{180,32,0},{180,30,0},{180,34,0}}, {count=4, randomize=true, veteran=true})
		
		civlua.createUnit(eburonesCavalry, belgaeTribe, {{136,26,0},{136,29,0},{136,30,0}}, {count=4, randomize=true, veteran=true})
		civlua.createUnit(eburonesSwordsmen, belgaeTribe, {{136,26,0},{136,29,0},{136,30,0}}, {count=6, randomize=true, veteran=true})
		civlua.createUnit(eburonesSpearmen, belgaeTribe, {{136,26,0},{136,29,0},{136,30,0}}, {count=6, randomize=true, veteran=true})
		civlua.createUnit(eburonesNobles, belgaeTribe, {{136,26,0},{136,29,0},{136,30,0}}, {count=2, randomize=true, veteran=true})
		
		--g loop over all units, and give series of gotoTile commands
		for u in civ.iterateUnits() do
			if u.owner.id==belgaeTribe.id and u.location.x >= 148 and u.location.x <= 186 and u.location.y >= 24 and u.location.y <= 46 then
				u.gotoTile = civ.getTile(181,31, 0)
			end
			if u.owner.id==belgaeTribe.id and u.location.x >= 139 and u.location.x <= 147 and u.location.y >= 33 and u.location.y <= 47 then
				u.gotoTile = civ.getTile(144,38, 0)
			end
			if u.owner.id==belgaeTribe.id and u.location.x >= 125 and u.location.x <= 135 and u.location.y >= 33 and u.location.y <= 43 then
				u.gotoTile = civ.getTile(129,37, 0)
			end
			if u.owner.id==belgaeTribe.id and u.location.x >= 136 and u.location.x <= 136 and u.location.y >= 26 and u.location.y <= 30 then
				u.gotoTile = civ.getTile(129,27, 0)
			end
		end
		
	end
	
	
--g Vercingetorix campaign - aggression starts once more than 12 cities have been conquered by rome
--g events.txt has a random factor in it, not yet included ...
	if numberOfConqueredCities >= 16 then
		justOnce("VercingetorixAgression", function ()
			civ.ui.text(func.splitlines("A council of leaders all across Gaul has decided that they must stand up to Caesar now, or never.  A charismatic young prince, Vercingetorix, has seized control in Gergovia and is crowned king! A shrewd diplomat, Vercingetorix has forged alliances with various tribes, and has assumed supreme command of their armies! All across Gaul, the tribes revolt!"))
			civ.makeAggression(averniTribe, romanTribe)
			state.vercingetorixUprising=1

			--g create units supporting the uprising - executed just once
		civlua.createUnit(celticSlingers, averniTribe, {{105,53,0},{103,57,0},{104,58,0}}, {count=4, randomize=true, veteran=false})
		civlua.createUnit(arverniSwordsmen, averniTribe, {{105,53,0},{103,57,0},{104,58,0}}, {count=4, randomize=true, veteran=false})
		civlua.createUnit(arverniNobles, averniTribe, {{105,53,0},{103,57,0},{104,58,0}}, {count=2, randomize=true, veteran=false})
		civlua.createUnit(arverniArchers, averniTribe, {{107,53,0},{107,49,0},{107,45,0}}, {count=4, randomize=true, veteran=false})
		civlua.createUnit(arverniCavalry, averniTribe, {{114,52,0},{118,54,0},{117,57,0},{119,59,0}}, {count=2, randomize=true, veteran=false})
		
		civlua.createUnit(arverniCavalry, averniTribe, {{102,86,0},{103,85,0},{104,86,0},{113,83,0},{109,79,0}}, {count=2, randomize=true, veteran=false})
		civlua.createUnit(arverniSwordsmen, averniTribe, {{102,86,0},{103,85,0},{104,86,0},{113,83,0},{109,79,0}}, {count=4, randomize=true, veteran=false})
		civlua.createUnit(arverniSwordsmen, averniTribe, {{102,86,0},{103,85,0},{104,86,0},{113,83,0},{109,79,0}}, {count=4, randomize=true, veteran=false})

		civlua.createUnit(arverniSwordsmen, averniTribe, {{153,77,0},{154,78,0},{150,78,0},{150,80,0},{148,78,0}}, {count=4, randomize=true, veteran=false})
		civlua.createUnit(celticSlingers, averniTribe, {{153,77,0},{154,78,0},{150,78,0},{150,80,0},{148,78,0}}, {count=4, randomize=true, veteran=false})
		civlua.createUnit(arverniNobles, averniTribe, {{153,77,0},{154,78,0},{150,78,0},{150,80,0},{148,78,0}}, {count=2, randomize=true, veteran=false})
		
		civlua.createUnit(arverniNobles, averniTribe, {{95,99,0},{95,97,0},{97,97,0},{100,98,0}}, {count=2, randomize=true, veteran=false})
		civlua.createUnit(arverniSwordsmen, averniTribe, {{95,99,0},{95,97,0},{97,97,0},{100,98,0}}, {count=4, randomize=true, veteran=false})
		civlua.createUnit(celticSlingers, averniTribe, {{95,99,0},{95,97,0},{97,97,0},{100,98,0}}, {count=4, randomize=true, veteran=false})

		civlua.createUnit(celticSlingers, averniTribe, {{54,68,0},{57,67,0},{56,64,0},{52,64,0},{53,67,0}}, {count=4, randomize=true, veteran=false})
		civlua.createUnit(arverniSwordsmen, averniTribe, {{54,68,0},{57,67,0},{56,64,0},{52,64,0},{53,67,0}}, {count=4, randomize=true, veteran=false})
		civlua.createUnit(arverniCavalry, averniTribe, {{54,68,0},{57,67,0},{56,64,0},{52,64,0},{53,67,0}}, {count=4, randomize=true, veteran=false})

		civlua.createUnit(venetiSpearmen, venetiiTribe, {{37,51,0},{40,50,0},{39,53,0},{46,52,0},{46,50,0}}, {count=4, randomize=true, veteran=false})
		civlua.createUnit(venetiSwordsmen, venetiiTribe, {{37,51,0},{40,50,0},{39,53,0},{46,52,0},{46,50,0}}, {count=4, randomize=true, veteran=false})
		civlua.createUnit(venetiArchers, venetiiTribe, {{37,51,0},{40,50,0},{39,53,0},{46,52,0},{46,50,0}}, {count=4, randomize=true, veteran=false})

		civlua.createUnit(venetiArchers, venetiiTribe, {{28,42,0},{30,40,0},{33,39,0},{31,45,0},{27,43,0}}, {count=4, randomize=true, veteran=false})
		civlua.createUnit(venetiSwordsmen, venetiiTribe, {{28,42,0},{30,40,0},{33,39,0},{31,45,0},{27,43,0}}, {count=4, randomize=true, veteran=false})
		civlua.createUnit(venetiSpearmen, venetiiTribe, {{28,42,0},{30,40,0},{33,39,0},{31,45,0},{27,43,0}}, {count=4, randomize=true, veteran=false})	
			--g end of unit creation
			
					--g delete units protecting the Arverni
			for u in civ.iterateUnits() do
				if u.type.id==alesiaProtectors.id then
					--[[--g restriction to map coordinates actually not needed, but for reference: entire map: --]] --and u.location.x >= 0 and u.location.x <= 280 and u.location.y >= 0 and u.location.y <= 124 then
					civ.deleteUnit(u)
				end
			end
			
		end)
	end

	--g create reinforcements near Lutetia as long as the uprising is going on and the romans have not yet conquered Lutetia
	if state.vercingetorixUprising == 1 and civ.getCity(cityID["Lutetia"]).owner.id ~= romanTribe.id then
	civlua.createUnit(celticSlingers, averniTribe, {{134,48,0},{133,49,0},{129,47,0}}, {count=3, randomize=true, veteran=false})
	civlua.createUnit(arverniSwordsmen, averniTribe, {{134,48,0},{133,49,0},{129,47,0}}, {count=3, randomize=true, veteran=false})
	--g or alternatively?: if state.vercingetorixUprising == 1 and state.citiesTaken.others.lutetia ~= true then
	end
	
	if state.vercingetorixUprising == 1 and civ.getCity(cityID["Avaricum"]).owner.id ~= romanTribe.id then
	civlua.createUnit(arverniCavalry, averniTribe, {{128,68,0},{129,67,0},{129,73,0},{133,73,0},{131,71,0}}, {count=3, randomize=true, veteran=false})
	civlua.createUnit(arverniSwordsmen, averniTribe, {{128,68,0},{129,67,0},{129,73,0},{133,73,0},{131,71,0}}, {count=3, randomize=true, veteran=false})
	--g or alternatively?: if state.vercingetorixUprising == 1 and state.citiesTaken.others.lutetia ~= true then
	end
	
	if state.vercingetorixUprising == 1 and civ.getCity(cityID["Cenabum"]).owner.id ~= romanTribe.id then
	civlua.createUnit(arverniCavalry, averniTribe, {{111,57,0},{112,54,0},{118,58,0},{112,60,0},{113,59,0}}, {count=3, randomize=true, veteran=false})
	civlua.createUnit(arverniSwordsmen, averniTribe, {{111,57,0},{112,54,0},{118,58,0},{112,60,0},{113,59,0}}, {count=3, randomize=true, veteran=false})
	--g or alternatively?: if state.vercingetorixUprising == 1 and state.citiesTaken.others.lutetia ~= true then
	end
	
	if state.vercingetorixUprising == 1 and civ.getCity(cityID["Noviodunum"]).owner.id ~= romanTribe.id then
	civlua.createUnit(arverniNobles, averniTribe, {{117,61,0},{115,61,0},{118,66,0},{119,65,0},{114,66,0}}, {count=3, randomize=true, veteran=false})
	civlua.createUnit(arverniSwordsmen, averniTribe, {{117,61,0},{115,61,0},{118,66,0},{119,65,0},{114,66,0}}, {count=3, randomize=true, veteran=false})
	--g or alternatively?: if state.vercingetorixUprising == 1 and state.citiesTaken.others.lutetia ~= true then
	end
	
	if state.vercingetorixUprising == 1 and civ.getCity(cityID["Gergovia"]).owner.id ~= romanTribe.id then
	civlua.createUnit(arverniNobles, averniTribe, {{107,85,0},{106,84,0},{108,86,0},{112,80,0},{111,79,0}}, {count=3, randomize=true, veteran=false})
	civlua.createUnit(arverniSwordsmen, averniTribe, {{107,85,0},{106,84,0},{108,86,0},{112,80,0},{111,79,0}}, {count=3, randomize=true, veteran=false})
	civlua.createUnit(arverniCavalry, averniTribe, {{107,85,0},{106,84,0},{108,86,0},{112,80,0},{111,79,0}}, {count=3, randomize=true, veteran=false})
	--g or alternatively?: if state.vercingetorixUprising == 1 and state.citiesTaken.others.lutetia ~= true then
	end
	
	if state.vercingetorixUprising == 1 and civ.getCity(cityID["Gergobina"]).owner.id ~= romanTribe.id then
	civlua.createUnit(arverniNobles, averniTribe, {{133,81,0},{139,81,0},{138,84,0},{132,80,0},{133,79,0}}, {count=3, randomize=true, veteran=false})
	civlua.createUnit(arverniSwordsmen, averniTribe, {{133,81,0},{139,81,0},{138,84,0},{132,80,0},{133,79,0}}, {count=3, randomize=true, veteran=false})
	--g or alternatively?: if state.vercingetorixUprising == 1 and state.citiesTaken.others.lutetia ~= true then
	end


	if state.vercingetorixUprising == 1 then
	
		--g create units every turn
				--g Create new units
		civlua.createUnit(celticSlingers, averniTribe, {{105,53,0},{103,57,0},{104,58,0}}, {count=1, randomize=true, veteran=false})
		civlua.createUnit(arverniSwordsmen, averniTribe, {{105,53,0},{103,57,0},{104,58,0}}, {count=1, randomize=true, veteran=false})
		civlua.createUnit(arverniNobles, averniTribe, {{105,53,0},{103,57,0},{104,58,0}}, {count=1, randomize=true, veteran=false})
		civlua.createUnit(arverniArchers, averniTribe, {{107,53,0},{107,49,0},{107,45,0}}, {count=1, randomize=true, veteran=false})
		civlua.createUnit(arverniCavalry, averniTribe, {{114,52,0},{118,54,0},{117,57,0},{119,59,0}}, {count=1, randomize=true, veteran=false})
		
		civlua.createUnit(arverniCavalry, averniTribe, {{102,86,0},{103,85,0},{104,86,0},{113,83,0},{109,79,0}}, {count=1, randomize=true, veteran=false})
		civlua.createUnit(arverniSwordsmen, averniTribe, {{102,86,0},{103,85,0},{104,86,0},{113,83,0},{109,79,0}}, {count=1, randomize=true, veteran=false})
		civlua.createUnit(arverniSwordsmen, averniTribe, {{102,86,0},{103,85,0},{104,86,0},{113,83,0},{109,79,0}}, {count=1, randomize=true, veteran=false})

		civlua.createUnit(arverniSwordsmen, averniTribe, {{153,77,0},{154,78,0},{150,78,0},{150,80,0},{148,78,0}}, {count=1, randomize=true, veteran=false})
		civlua.createUnit(celticSlingers, averniTribe, {{153,77,0},{154,78,0},{150,78,0},{150,80,0},{148,78,0}}, {count=1, randomize=true, veteran=false})
		civlua.createUnit(arverniNobles, averniTribe, {{153,77,0},{154,78,0},{150,78,0},{150,80,0},{148,78,0}}, {count=1, randomize=true, veteran=false})
		
		civlua.createUnit(arverniNobles, averniTribe, {{95,99,0},{95,97,0},{97,97,0},{100,98,0}}, {count=1, randomize=true, veteran=false})
		civlua.createUnit(arverniSwordsmen, averniTribe, {{95,99,0},{95,97,0},{97,97,0},{100,98,0}}, {count=1, randomize=true, veteran=false})
		civlua.createUnit(celticSlingers, averniTribe, {{95,99,0},{95,97,0},{97,97,0},{100,98,0}}, {count=1, randomize=true, veteran=false})

		civlua.createUnit(celticSlingers, averniTribe, {{54,68,0},{57,67,0},{56,64,0},{52,64,0},{53,67,0}}, {count=1, randomize=true, veteran=false})
		civlua.createUnit(arverniSwordsmen, averniTribe, {{54,68,0},{57,67,0},{56,64,0},{52,64,0},{53,67,0}}, {count=1, randomize=true, veteran=false})
		civlua.createUnit(arverniCavalry, averniTribe, {{54,68,0},{57,67,0},{56,64,0},{52,64,0},{53,67,0}}, {count=1, randomize=true, veteran=false})

	
			--g end of unit creation

	
		--g loop over all units, and give series of gotoTile commands
		for u in civ.iterateUnits() do
			if u.owner.id==averniTribe.id and u.location.x >= 100 and u.location.x <= 122 and u.location.y >= 44 and u.location.y <= 58 then
				u.gotoTile = civ.getTile(85,39, 0)
			end
			if u.owner.id==averniTribe.id and u.location.x >= 98 and u.location.x <= 114 and u.location.y >= 78 and u.location.y <= 90 then
				u.gotoTile = civ.getTile(108,82, 0)
			end
			if u.owner.id==averniTribe.id and u.location.x >= 147 and u.location.x <= 159 and u.location.y >= 75 and u.location.y <= 81 then
				u.gotoTile = civ.getTile(164,70, 0)
			end
			if u.owner.id==averniTribe.id and u.location.x >= 91 and u.location.x <= 105 and u.location.y >= 95 and u.location.y <= 105 then
				u.gotoTile = civ.getTile(99,91, 0)
			end
			if u.owner.id==averniTribe.id and u.location.x >= 48 and u.location.x <= 62 and u.location.y >= 60 and u.location.y <= 70 then
				u.gotoTile = civ.getTile(59,61, 0)
			end
			if u.owner.id==venetiiTribe.id and u.location.x >= 36 and u.location.x <= 48 and u.location.y >= 44 and u.location.y <= 60 then
				u.gotoTile = civ.getTile(43,53, 0)
			end
			if u.owner.id==venetiiTribe.id and u.location.x >= 24 and u.location.x <= 34 and u.location.y >= 36 and u.location.y <= 48 then
				u.gotoTile = civ.getTile(21,41, 0)
			end
		end
		
	end --end of germanic invasion spawn
	

	
	--g Caesar's fall - spawn relentless hordes :)
	if state.caesarKilled==1 then
	
		civlua.createUnit(arverniSpearmen, averniTribe, {{159,67,0},{140,52,0},{114,52,0},{106,80,0},{100,94,0},{129,85,0},{134,78,0},{129,73,0},{132,46,0}}, {count=6, randomize=true, veteran=false})
		civlua.createUnit(arverniSwordsmen, averniTribe, {{159,67,0},{140,52,0},{114,52,0},{106,80,0},{100,94,0},{129,85,0},{134,78,0},{129,73,0},{132,46,0}}, {count=5, randomize=true, veteran=false})
		civlua.createUnit(arverniCavalry, averniTribe, {{159,67,0},{140,52,0},{114,52,0},{106,80,0},{100,94,0},{129,85,0},{134,78,0},{129,73,0},{132,46,0}}, {count=3, randomize=true, veteran=false})
		civlua.createUnit(arverniNobles, averniTribe, {{159,67,0},{140,52,0},{114,52,0},{106,80,0},{100,94,0},{129,85,0},{134,78,0},{129,73,0},{132,46,0}}, {count=2, randomize=true, veteran=false})
		civlua.createUnit(arverniSpearmen, averniTribe, {{159,67,0},{140,52,0},{114,52,0},{106,80,0},{100,94,0},{129,85,0},{134,78,0},{129,73,0},{132,46,0}}, {count=5, randomize=true, veteran=false})
	
		civlua.createUnit(belgaeWarriors, belgaeTribe, {{127,43,0},{126,38,0},{129,47,0},{142,36,0},{131,27,0},{129,85,0},{183,29,0},{165,49,0}}, {count=5, randomize=true, veteran=false})
		civlua.createUnit(belgaeWarriors, belgaeTribe, {{127,43,0},{126,38,0},{129,47,0},{142,36,0},{131,27,0},{129,85,0},{183,29,0},{165,49,0}}, {count=5, randomize=true, veteran=true})
		civlua.createUnit(belgaeWarriors, belgaeTribe, {{127,43,0},{126,38,0},{129,47,0},{142,36,0},{131,27,0},{129,85,0},{183,29,0},{165,49,0}}, {count=5, randomize=true, veteran=false})
		civlua.createUnit(belgaeWarriors, belgaeTribe, {{127,43,0},{126,38,0},{129,47,0},{142,36,0},{131,27,0},{129,85,0},{183,29,0},{165,49,0}}, {count=5, randomize=true, veteran=true})
		civlua.createUnit(belgaeNobles, belgaeTribe, {{127,43,0},{126,38,0},{129,47,0},{142,36,0},{131,27,0},{129,85,0},{183,29,0},{165,49,0}}, {count=3, randomize=true, veteran=true})

	end
	
	
	--g recruitment of roman legions
	if romanTribe:hasTech(civ.getTech(2)) then
		justOnce("RecruitXIIIXIV", function ()
			civ.playSound('Eagle.wav')
			civ.ui.text(func.splitlines("Legio XIII 'Gemina' is recruited near Genua!"))
			civlua.createUnit(legioXIIIGemina, romanTribe, {{217,111,0},{216,112,0},{214,112,0}}, {count=1, randomize=false, veteran=false})
			civ.ui.text(func.splitlines("Legio XIV 'G.M.V' is recruited near Genua!"))
			civlua.createUnit(legioXIVGMV, romanTribe, {{214,112,0},{216,112,0},{217,111,0}}, {count=1, randomize=false, veteran=false})
		end) 
	end

	if romanTribe:hasTech(civ.getTech(3)) then
		justOnce("RecruitI", function ()
			if turn<96 then 
				civ.playSound('Eagle.wav')
				civ.ui.text(func.splitlines("Caesar borrows Pompey's First Legion for his campaign. It marches into southern Gaul to join the fight."))
				civlua.createUnit(legioIGermanica, romanTribe, {{145,109,0},{143,109,0},{139,109,0}}, {count=1, randomize=false, veteran=false})
			else
				civ.ui.text(func.splitlines("Caesar asks Pompey for his support in the invasion of Gaul - but it is too late and the conflict of their ambitions is too clear. Pompey refuses the request!"))
			end
		end) 
	end

	if romanTribe:hasTech(civ.getTech(4)) then
		justOnce("RecruitXV", function ()
			civ.playSound('Eagle.wav')
			civ.ui.text(func.splitlines("Legio XV 'Apollinaris' is recruited in Cisalpine Gaul! It marches towards a mountain pass to join the fight!"))
			civlua.createUnit(legioXVApollinaris, romanTribe, {{199,103,0},{196,100,0},{207,101,0}}, {count=1, randomize=false, veteran=false})
		end) 
	end

	if romanTribe:hasTech(civ.getTech(6)) then
		justOnce("RecruitVVI", function ()
			civ.playSound('Eagle.wav')
			civ.ui.text(func.splitlines("Legio V 'Alaudae' is recruited in Transalpine Gaul! Breaking with tradition, it is the first legion raised from non-citizens."))
			civlua.createUnit(legioVAlaudae, romanTribe, {{123,115,0},{119,115,0},{127,113,0}}, {count=1, randomize=false, veteran=false})
			civ.ui.text(func.splitlines("Legio VI 'Ferrata' is recruited in Cisalpine Gaul! "))
			civlua.createUnit(legioVIFerrata, romanTribe, {{225,99,0},{228,100,0},{234,104,0}}, {count=1, randomize=false, veteran=false})
		end) 
	end

	--g check destruction of roman legions
	if destroyedLegions() >= 3 then
		justOnce("ThreeLegionsDestroyed", function ()
			civ.ui.text(func.splitlines("The loss of three legions is devastating to Roman morale.  The campaign is not going well at all."))
			civ.giveTech(romanTribe, civ.getTech(90))
		end)
	end
	
	if destroyedLegions() >= 6 then
		justOnce("SixLegionsDestroyed", function ()
			civ.ui.text(func.splitlines("This campaign is turning into a disaster.  The Romans have lost their sixth prized legion!"))
			civ.giveTech(romanTribe, civ.getTech(91))
		end)
	end
	
	if destroyedLegions() >= 9 then
		justOnce("NineLegionsDestroyed", function ()
			civ.ui.text(func.splitlines("This campaign is a complete and total disaster.  Nine legions of Rome have been annihilated."))
			civ.giveTech(romanTribe, civ.getTech(92))
		end)
	end
	

end)

------------------------------------------------------------------------------------------------------------------------------------------------
-- onUnitKilled --------------------------------------------------------------------------------------------------------------------------------

civ.scen.onUnitKilled(function (killed, killedBy)
	local id = killed.type.id
	local attacker = civ.getCurrentTribe() 
	
	--g get the movement multiplier for the calculation of the "no movement reduction destructions" :)
	local multiplier = civ.cosmic.roadMultiplier
	
	--g Destruction of artillery munition etc - movement point is restored
	for _, typeToBeDestroyedWithoutReduction in pairs(unitTypesWhichCanBeDestroyedWithoutMovementReduction) do
		if id==typeToBeDestroyedWithoutReduction and killed.owner.id ~= attacker.id then
			--g if munition is killed while defending (so not if the defender manages to destroy the attacking munition ...), then increase movement points / decrease move spent
			local newSpent=killedBy.moveSpent-multiplier
			if newSpent<0 then newSpent=0 end
			killedBy.moveSpent=newSpent
		end
	end
	
	--g Alesia event
	if id == wallsOfAlesiaTownfolkUnit.id then
		if killedBy.owner.id ~= romanTribe.id then
			--g if not killed by romans - do nothing. Or recreate townfolk perhaps?
		else
			--g if the townfolk is killed by romans, then trigger main alesia event - but do this JustOnce
			justOnce("CreatedWallsOfAlesia", function ()
 
			civ.ui.text(func.splitlines(wallsOfAlesiaText))
			
			--g first change terrain to create the walls
			for __,location in ipairs(wallsOfAlesiaLocations) do
				civ.getTile(location[1], location[2], location[3]).terrainType = wallsOfAlesiaTerrainType
			end
			
			--g secondly deploy reinforcements
			civlua.createUnit(vercingetorix, averniTribe, {{169,53,0}}, {randomize=false, veteran=false})
			
			civlua.createUnit(celticOppidum, averniTribe, {{169,53,0}}, {count=4, randomize=false, veteran=true})
			civlua.createUnit(arverniNobles, averniTribe, {{169,53,0}}, {count=6, randomize=false, veteran=true})
			civlua.createUnit(arverniArchers, averniTribe, {{169,53,0}}, {count=6, randomize=false, veteran=true})
			civlua.createUnit(arverniSwordsmen, averniTribe, {{169,53,0}}, {count=6, randomize=false, veteran=true})
			civlua.createUnit(arverniSwordsmen, averniTribe, {{156,56,0},{157,59,0},{159,61,0},{158,56,0},{165,59,0},{168,60,0},{173,57,0},{169,59,0},{164,50,0},{163,55,0}}, {count=15, randomize=true, veteran=true})
			civlua.createUnit(arverniSwordsmen, averniTribe, {{158,56,0},{159,61,0},{157,59,0},{156,56,0},{165,59,0},{168,60,0},{173,57,0},{169,59,0},{164,50,0},{163,55,0}}, {count=15, randomize=true, veteran=true})
			civlua.createUnit(arverniSwordsmen, averniTribe, {{163,45,0},{159,57,0},{155,55,0},{165,59,0},{168,60,0},{173,57,0},{169,59,0},{164,50,0},{163,55,0}}, {count=7, randomize=true, veteran=true})
			civlua.createUnit(arverniSwordsmen, averniTribe, {{155,55,0},{159,57,0},{155,59,0},{165,59,0},{168,60,0},{173,57,0},{169,59,0},{164,50,0},{163,55,0}}, {count=7, randomize=true, veteran=true})
			civlua.createUnit(arverniSwordsmen, averniTribe, {{163,45,0},{159,57,0},{155,55,0},{165,59,0},{168,60,0},{173,57,0},{169,59,0},{164,50,0},{163,55,0}}, {count=7, randomize=true, veteran=true})
			civlua.createUnit(arverniSwordsmen, averniTribe, {{155,55,0},{159,57,0},{155,59,0},{165,59,0},{168,60,0},{173,57,0},{169,59,0},{164,50,0},{163,55,0}}, {count=7, randomize=true, veteran=true})
			
			civlua.createUnit(arverniArchers, averniTribe, {{157,59,0},{159,49,0},{160,46,0},{156,44,0},{165,59,0},{168,60,0},{173,57,0},{169,59,0},{164,50,0},{163,55,0}}, {count=5, randomize=true, veteran=true})
			civlua.createUnit(arverniArchers, averniTribe, {{157,59,0},{159,49,0},{160,46,0},{156,44,0},{165,59,0},{168,60,0},{173,57,0},{169,59,0},{164,50,0},{163,55,0}}, {count=5, randomize=true, veteran=true})
			civlua.createUnit(arverniArchers, averniTribe, {{156,44,0},{159,49,0},{160,46,0},{157,59,0},{165,59,0},{168,60,0},{173,57,0},{169,59,0},{164,50,0},{163,55,0}}, {count=5, randomize=true, veteran=true})
			civlua.createUnit(arverniArchers, averniTribe, {{160,46,0},{156,44,0},{159,49,0},{157,59,0},{165,59,0},{168,60,0},{173,57,0},{169,59,0},{164,50,0},{163,55,0}}, {count=5, randomize=true, veteran=true})
			civlua.createUnit(arverniArchers, averniTribe, {{159,49,0},{160,46,0},{156,44,0},{157,59,0},{165,59,0},{168,60,0},{173,57,0},{169,59,0},{164,50,0},{163,55,0}}, {count=5, randomize=true, veteran=true})

			civlua.createUnit(arverniCavalry, averniTribe, {{155,59,0},{179,55,0},{179,53,0},{163,43,0},{165,59,0},{168,60,0},{173,57,0},{169,59,0},{164,50,0},{163,55,0}}, {count=8, randomize=true, veteran=true})
			civlua.createUnit(arverniSwordsmen, averniTribe, {{161,55,0},{161,59,0},{163,51,0},{164,48,0},{165,59,0},{168,60,0},{173,57,0},{169,59,0},{164,50,0},{163,55,0}}, {count=8, randomize=true, veteran=true})
			civlua.createUnit(arverniSpearmen, averniTribe, {{172,48,0},{176,50,0},{176,54,0},{178,50,0},{165,59,0},{168,60,0},{173,57,0},{169,59,0},{164,50,0},{163,55,0}}, {count=8, randomize=true, veteran=true})

			civlua.createUnit(arverniNobles, averniTribe, {{160,46,0},{156,44,0},{155,59,0},{179,55,0},{165,59,0},{168,60,0},{173,57,0},{169,59,0},{164,50,0},{163,55,0}}, {count=4, randomize=true, veteran=true})
			civlua.createUnit(arverniNobles, averniTribe, {{156,44,0},{160,46,0},{155,59,0},{179,55,0},{165,59,0},{168,60,0},{173,57,0},{169,59,0},{164,50,0},{163,55,0}}, {count=4, randomize=true, veteran=true})
			civlua.createUnit(arverniNobles, averniTribe, {{153,49,0},{155,55,0},{159,57,0},{165,59,0},{168,60,0},{173,57,0},{169,59,0},{164,50,0},{163,55,0}}, {count=4, randomize=true, veteran=true})
		
			--g and thirdly, give MoveUnit Command
			--g loop over all units, check if they are Arverni units within the rectangle 141,41,181,41,181,65,141,65, and if so, give gotoTile command
			for u in civ.iterateUnits() do
				if u.owner.id==averniTribe.id and u.location.x >= 141 and u.location.x <= 181 and u.location.y >= 41 and u.location.y <= 65 then
					u.gotoTile = civ.getTile(169, 53, 0)
				end
			end
			
			end)
		end
	end
  	--g Alesia event done
	
	--g romans defeat civilian units
	if id == helvetiiMigrations.id and killed.owner.id == helvetiiTribe.id and killedBy.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Roman soldiers loot a Helvetii baggage train!"))
		romanTribe.money = romanTribe.money + 200
	end
	if id == helvetiiRefugees.id and killed.owner.id == helvetiiTribe.id and killedBy.owner.id == romanTribe.id then
		--g legacy: civ.ui.text(func.splitlines("Plunder from the Helvetii is brought to Massilia! These units can be 'disbanded' to help rush-build other items."))
		--g legacy: civlua.createUnit(romanSlaves, romanTribe, {{156,120,0}}, {randomize=false, veteran=false})
		civ.ui.text(func.splitlines("Helvetii refuguees are caught unproteced on the roads. Their future lies now in Roman chains while the meager bits of gold they carried are sent to the Roman coffers. (These units can be 'disbanded' to help rush-build other items.)"))
		civlua.createUnit(romanSlaves, romanTribe, {{killedBy.location.x,killedBy.location.y,killedBy.location.z}}, {randomize=false, veteran=false})
		romanTribe.money = romanTribe.money + 25
	end
	if id == gallicTownfolk.id and killedBy.owner.id == romanTribe.id then
		--g legacy: civ.ui.text(func.splitlines("Plunder from Gaul is brought to Massilia! These units can be 'disbanded' to help rush-build other items."))
		--g legacy: civlua.createUnit(romanSlaves, romanTribe, {{156,120,0}}, {randomize=false, veteran=false})
		civ.ui.text(func.splitlines("Gallic townfolk are caught unproteced on the roads. Their future lies now in Roman chains while the meager bits of gold they carried are sent to the Roman coffers. (These units can be 'disbanded' to help rush-build other items.)"))
		civlua.createUnit(romanSlaves, romanTribe, {{killedBy.location.x,killedBy.location.y,killedBy.location.z}}, {randomize=false, veteran=false})
		romanTribe.money = romanTribe.money + 25
	end
	if id == germanicVillagers.id and killedBy.owner.id == romanTribe.id then
		--g legacy: civ.ui.text(func.splitlines("Plunder from Germania is brought to Massilia! These units can be 'disbanded' to help rush-build other items."))
		--g legacy: civlua.createUnit(romanSlaves, romanTribe, {{156,120,0}}, {randomize=false, veteran=false})
		civ.ui.text(func.splitlines("Germanic villagers are caught unproteced on the roads. Their future lies now in Roman chains while the meager bits of gold they carried are sent to the Roman coffers. (These units can be 'disbanded' to help rush-build other items.)"))
		civlua.createUnit(romanSlaves, romanTribe, {{killedBy.location.x,killedBy.location.y,killedBy.location.z}}, {randomize=false, veteran=false})
		romanTribe.money = romanTribe.money + 25
	end
	if id == germanicVillage.id and killedBy.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Roman soldiers loot a village in Germania!"))
		romanTribe.money = romanTribe.money + 200
	end
	if id == holySite.id and killedBy.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Roman soldiers destroy a pagan holy site, carting off its offerings!"))
		romanTribe.money = romanTribe.money + 600
	end
	
	--g Events for Germanic campaign
	if id == eerieForest.id and killed.owner.id == germanicTribe.id and killedBy.owner.id == romanTribe.id then
		civ.playSound('Victory.wav')
		civ.ui.text(func.splitlines("The advancing Romans find eerie forests and howling nights.  Their adventure is brief and limited, but it does dissuade the German tribes from launching further raids.  Back in Rome, the people are starstruck by tales of Caesar's daring in bridging the Rhine.  Stories are told, and Caesar's prestige increases (The Romans can now build the Wonder 'De Provinciis Consularibus')."))
		--g Germanic invasion ends
		state.germanicInvasion=0
		civ.giveTech(romanTribe, civ.getTech(77))
	end
	
	if id == buildRhineBridge.id and killed.owner.id == germanicTribe.id  then
		if killedBy.owner.id == romanTribe.id then
			civ.ui.text(func.splitlines("In a show of exceptional military engineering, Caesar builds a bridge over the Rhine in just 10 days."))
			civlua.createUnit(destroyBridge, germanicTribe, {{221,41,0},{225,43,0}}, {randomize=false, veteran=false})
			civ.getTile(222, 44, 0).terrainType = bridgeOverTheRhineTerrain
		else
			--g if anyone but the romans destroys the unit - replace it!
			civlua.createUnit(buildRhineBridge, germanicTribe, {{221,45,0},{219,45,0},{221,47,0}}, {randomize=false, veteran=false})
		end
	end
	if id == destroyBridge.id and killed.owner.id == germanicTribe.id and killedBy.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Soon after raiding Germany (historically, 18 days), Caesar withdraws his forces across the Rhine and demolishes the bridge."))
		civ.getTile(222, 44, 0).terrainType = destroyedBridgeTerrain
	end

	if id == ariovistus.id and killed.owner.id == germanicTribe.id and killedBy.owner.id == romanTribe.id then
       if state.ariovistusDefeated==0 then
           civ.ui.text(func.splitlines("Ariovistus has escaped across the Rhine, outside our clutches! His followers continue to harrass our eastern flank, near Vesontio! We must press on to Germania to end this threat! Yet in our way stands the mighty Rhine River!"))
           state.ariovistusDefeated=1
           civlua.createUnit(ariovistus, germanicTribe, {{238,14,0},{251,11,0},{242,44,0}}, {randomize=false, veteran=true})
       elseif state.ariovistusDefeated==1 then
       	   civ.playSound('Victory.wav')
           civ.ui.text(func.splitlines("We have pursued and captured Ariovistus across the Rhine! Forever grateful, our Aeduian Allies pay us 5,000 denarii!"))
           state.ariovistusDefeated=2
           romanTribe.money = romanTribe.money + 5000
       end
   end

	
	--g Belgica campaign
	if state.belgaeMobilization==0 and killed.owner.id == belgaeTribe.id and killedBy.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Caesar marches into Belgica, determined to secure a source of grain.  He meets fierce resistance, leading him to write, 'Horum omnium fortissimi sunt Belgae.'"))
		state.belgaeMobilization=1
	end
		
	--g Ambiorix defeat
	if id == ambiorix.id and killed.owner.id == belgaeTribe.id and killedBy.owner.id == romanTribe.id then
		civ.playSound('Victory.wav')
		civ.ui.text(func.splitlines("Ambiorix is slain, and his rebellion put down.  Though a few fanatics make one final last stand, it is only a matter of time until Belgica is once again largely subdued."))
		civ.giveTech(romanTribe, civ.getTech(87))
		state.ambiorixUprising=0
	end
	
	--g Vercingetorix defeat
	if id == vercingetorix.id and killed.owner.id == averniTribe.id and killedBy.owner.id == romanTribe.id then
		civ.playSound('Vercingetorix.wav')
		civ.ui.text(func.splitlines("Vercingetorix bends the knee to Caesar! His capture largely ends the Great Gallic Revolt, though there are still mopping up operations to complete.  Caesar has the Gallic rebel brought to Rome in shackels for an eventual Triumph."))
		civ.giveTech(romanTribe, civ.getTech(76))
		state.vercingetorixUprising=0
	end
	
	--g Britannia
	if id == druids.id and killedBy.owner.id == romanTribe.id then
		civ.playSound('Victory.wav')
		civ.ui.text(func.splitlines("For as long as time could remember, there had been tales of a mysterious island, far to the north. Caesar's daring in exploring these lands has sparked the imagination of Romans everywhere!" ))
		civ.giveTech(romanTribe, civ.getTech(78))
	end
	

	--g Caesar's fall
	if id == caesar.id and killed.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Gaius Julius Caesar dies in battle, and although his leading general adopts his name and carries on the fight, the Gauls are so emboldened by his death that it may prove impossible to pacify them now."))
		state.caesarKilled=1
		civ.giveTech(romanTribe, civ.getTech(30))
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=aquileia, count=6, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=narbo, count=6, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=mediolanum, count=6, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=genua, count=6, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=massilia, count=6, randomize=false, veteran=false})
	end
	
	--g Labienus' fall
	if id == labienus.id and killed.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Caesar's trusted deputy, Titus Labienus, dies in battle.  When news reaches Roman territory, citizens become gripped with fear."))
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=aquileia, count=3, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=narbo, count=3, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=mediolanum, count=3, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=genua, count=3, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=massilia, count=3, randomize=false, veteran=false})
	end
	
	--g Marc Antony's fall
	if id == marcAntony.id and killed.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Caesar's trusted deputy, Marc Antony, dies in battle.  When news reaches Roman territory, citizens become gripped with fear."))
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=aquileia, count=3, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=narbo, count=3, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=mediolanum, count=3, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=genua, count=3, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=massilia, count=3, randomize=false, veteran=false})
	end
	
	--g destroyed legions
	if id == legioIGermanica.id and killed.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Legio I 'Germanica' is destroyed in Battle.  Pompey is furious at the loss of his prized legion, and the Roman people near panic."))
		state.legio01Destroyed=1
		state.legioDestroyed.legio01 = true
		civ.giveTech(romanTribe, civ.getTech(57))
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=aquileia, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=narbo, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=mediolanum, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=genua, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=massilia, count=2, randomize=false, veteran=false})
	end
	
	if id == legioVAlaudae.id and killed.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Legio V 'Alaudae' is destroyed in Battle.  The Roman people are gripped with fear."))
		state.legio05Destroyed=1
		state.legioDestroyed.legio05 = true
		civ.giveTech(romanTribe, civ.getTech(58))
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=aquileia, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=narbo, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=mediolanum, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=genua, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=massilia, count=2, randomize=false, veteran=false})
	end
	
	if id == legioVIFerrata.id and killed.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Legio VI 'Ferrata' is destroyed in Battle.  The 'Ironside Legion' had no chance against the relentless attacks."))
		state.legio06Destroyed=1
		state.legioDestroyed.legio06 = true
		civ.giveTech(romanTribe, civ.getTech(59))
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=aquileia, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=narbo, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=mediolanum, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=genua, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=massilia, count=2, randomize=false, veteran=false})
	end
	
	if id == legioVIIClaudia.id and killed.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Legio VII 'Claudia' is destroyed in Battle. This is a terrible blow to Roman morale."))
		state.legio07Destroyed=1
		state.legioDestroyed.legio07 = true
		civ.giveTech(romanTribe, civ.getTech(61))
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=aquileia, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=narbo, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=mediolanum, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=genua, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=massilia, count=2, randomize=false, veteran=false})
	end
	
	if id == legioVIIIAugusta.id and killed.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Legio VIII 'Augusta' is destroyed in Battle.  This is a terrible blow to Roman morale."))
		state.legio08Destroyed=1
		state.legioDestroyed.legio08 = true
		civ.giveTech(romanTribe, civ.getTech(52))
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=aquileia, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=narbo, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=mediolanum, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=genua, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=massilia, count=2, randomize=false, veteran=false})
	end
	
	if id == legioIXHispana.id and killed.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Legio IX 'Hispana' is destroyed in Battle. This is a terrible blow to Roman morale."))
		state.legio09Destroyed=1
		state.legioDestroyed.legio09 = true
		civ.giveTech(romanTribe, civ.getTech(63))
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=aquileia, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=narbo, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=mediolanum, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=genua, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=massilia, count=2, randomize=false, veteran=false})
	end
	
	if id == legioXFretensis.id and killed.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Caesar's prized Legion, X 'Fretensis', is destroyed in Battle.  This is a terrible blow to Roman morale.  Caesar himself seems a changed man."))
		state.legio10Destroyed=1
		state.legioDestroyed.legio10 = true
		civ.giveTech(romanTribe, civ.getTech(38))
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=aquileia, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=narbo, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=mediolanum, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=genua, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=massilia, count=2, randomize=false, veteran=false})
	end
	
	if id == legioXIFidelis.id and killed.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Legio XI 'Fidelis' is destroyed in Battle.  This is a terrible blow to Roman morale."))
		state.legio11Destroyed=1
		state.legioDestroyed.legio11 = true
		civ.giveTech(romanTribe, civ.getTech(64))
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=aquileia, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=narbo, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=mediolanum, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=genua, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=massilia, count=2, randomize=false, veteran=false})
	end
	
	if id == legioXIIFulminata.id and killed.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Legio XII 'Fulminata' is destroyed in Battle. This is a terrible blow to Roman morale."))
		state.legio12Destroyed=1
		state.legioDestroyed.legio12 = true
		civ.giveTech(romanTribe, civ.getTech(65))
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=aquileia, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=narbo, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=mediolanum, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=genua, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=massilia, count=2, randomize=false, veteran=false})
	end
	
	if id == legioXIIIGemina.id and killed.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Legio XIII 'Gemina' is destroyed in Battle.  This is a terrible blow to Roman morale."))
		state.legio13Destroyed=1
		state.legioDestroyed.legio13 = true
		civ.giveTech(romanTribe, civ.getTech(72))
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=aquileia, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=narbo, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=mediolanum, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=genua, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=massilia, count=2, randomize=false, veteran=false})
	end
	
	if id == legioXIVGMV.id and killed.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Legio XIV 'G.M.V' is caught unaware and destroyed while gathering grain.  Their commander is disgraced!"))
		state.legio14Destroyed=1
		state.legioDestroyed.legio14 = true
		civ.giveTech(romanTribe, civ.getTech(73))
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=aquileia, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=narbo, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=mediolanum, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=genua, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=massilia, count=2, randomize=false, veteran=false})
	end
	
	if id == legioXVApollinaris.id and killed.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Legio XV 'Apollinaris' is destroyed in Battle. Their commander is disgraced! The Roman people quiver in panic!"))
		state.legio15Destroyed=1
		state.legioDestroyed.legio15 = true
		civ.giveTech(romanTribe, civ.getTech(81))
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=aquileia, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=narbo, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=mediolanum, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=genua, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=massilia, count=2, randomize=false, veteran=false})
	end
	
	--g massacre of roman civilians
	if id == citizens.id and killed.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Roman citizens are massacred! Memories of Brennus uttering, 'Vae Victis,' spring to mind! This causes a panic in nearby cities!"))
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=aquileia, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=narbo, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=mediolanum, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=genua, count=2, randomize=false, veteran=false})
		civlua.createUnit(massacre, romanTribe, {{220,124,0}}, {homeCity=massilia, count=2, randomize=false, veteran=false})
	end
	
	if id == gallicTownfolk.id and killed.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("Rampaging barbarians overrun Aedui townfolk.  Our Allies are upset at our lack of protection, and some nobles withdraw their support."))
		romanTribe.money = romanTribe.money - 200
	end
		
	
end)

------------------------------------------------------------------------------------------------------------------------------------------------
-- onCityKilled --------------------------------------------------------------------------------------------------------------------------------

civ.scen.onCityTaken(function (city, defender)
	--g the conqueror of the city has to be the currently active tribe
	local conqueror = civ.getCurrentTribe() 

	--g if Genavam is taken by the romans -> set persistent flag "genavamTaken", which stops the continuous spawning of Helvetii troops
	--g perform this only once
	if city.id == cityID["Genavam"] and defender.id == helvetiiTribe.id and conqueror.id == romanTribe.id then
		justOnce("takenGenavam", function ()
			civ.playSound('Victory.wav')
			civ.ui.text(func.splitlines("Seeing their army crushed, the majority of surviving Helvetii return to their burning homeland.  Once the Legions hunt down the stragglers, the Great Migration will be but a memory."))
			state.genavamTaken = 1
			
			--g Helvetii migration may be over, but Germanic invasion is just beginning ...
			civ.ui.text(func.splitlines("The Suebi king, Ariovistus, had been a friend of Rome, but those days are long gone.  A few years ago, he took hostages from our Aeduian Allies.  Now, his people constantly raid their lands and terrorize their people.  Caesar has demanded that this practice stop, and that the hostages be returned.  Ariovistus has refused, and dared us to attack.  Attack we shall... "))
			civ.makeAggression(germanicTribe, romanTribe)
			state.germanicInvasion=1

			civlua.createUnit(ariovistus, germanicTribe, {{179,71,0},{180,74,0},{181,73,0},{181,75,0},{182,70,0}}, {randomize=true, veteran=true})
			
			civlua.createUnit(germanSwordsmen, germanicTribe, {{180,74,0},{181,73,0},{179,71,0},{181,75,0},{182,70,0}}, {count=12, randomize=true, veteran=false})
			civlua.createUnit(germanCavalry, germanicTribe, {{181,75,0},{180,74,0},{181,73,0},{179,71,0},{182,70,0}}, {count=4, randomize=true, veteran=true})
			civlua.createUnit(germanNobles, germanicTribe, {{182,70,0},{181,75,0},{180,74,0},{181,73,0},{179,71,0}}, {count=6, randomize=true, veteran=true})
			civlua.createUnit(germanSkirmishers, germanicTribe, {{180,74,0},{182,70,0},{181,75,0},{181,73,0},{179,71,0}}, {count=8, randomize=true, veteran=true})
		
			--g loop over all units, check if they are Barbarian units within the rectangle 175,67,191,67,191,81,175,81, and if so, give gotoTile command
			for u in civ.iterateUnits() do
				if u.owner.id==germanicTribe.id and u.location.x >= 175 and u.location.x <= 191 and u.location.y >= 67 and u.location.y <= 81 then
					u.gotoTile = civ.getTile(164,70, 0)
				end
			end
		
		end)
	end
	

	--if city.id == cityID["Samarobriva"] and defender.id == belgaeTribe.id and conqueror.id == romanTribe.id then
	if city.id == cityID["Samarobriva"] and conqueror.id == romanTribe.id then
		--state.samarobrivaTaken=1
		state.citiesTaken.belgae.samarobrivaTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{129,35,0},{126,36,0}}, {count=1, randomize=false, veteran=false})
	
		justOnce("takenSamarobriva", function ()
			civ.ui.text(func.splitlines("The Romans sack Samarobriva! Desperate Gallic Townfolk flee into the countryside! Meanwhile, a band of warriors gathers for a counterattack!"))
					
			civlua.createUnit(belgaeWarriors, belgaeTribe, {{127,35,0},{129,35,0},{131,35,0},{133,35,0}}, {count=6, randomize=true, veteran=true})
			civlua.createUnit(belgaeWarriors, belgaeTribe, {{133,31,0},{131,31,0},{129,31,0},{126,34,0}}, {count=6, randomize=true, veteran=true})
			
		
		end)

	end
		
	if city.id == cityID["Portus Itius"] and conqueror.id == romanTribe.id then
		civ.ui.text(func.splitlines("The Romans march on Portus Itius! Gallic Townfolk flee into the countryside! While hunting them down, the Romans can't help but admire the gleeming island shimmering in the distance.  If we can force a landing there and defeat a druid, poets will sing our praises!"))
		state.citiesTaken.belgae.portusItiusTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{131,27,0},{132,26,0}}, {count=1, randomize=false, veteran=false})
	end

	if city.id == cityID["Nemotecena"] and conqueror.id == romanTribe.id then
		civ.ui.text(func.splitlines("The Romans sack Nemotecena! Desperate Gallic Townfolk flee into the countryside!"))
		state.citiesTaken.belgae.nemotecenaTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{142,36,0},{144,34,0}}, {count=1, randomize=false, veteran=false})
	end

	if city.id == cityID["Aduatuca"] and conqueror.id == romanTribe.id then
		civ.ui.text(func.splitlines("The Romans sack Aduatuca! Desperate Gallic Townfolk flee into the countryside!"))
		state.citiesTaken.belgae.aduatucaTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{183,29,0},{182,28,0}}, {count=1, randomize=false, veteran=false})
	
		justOnce("takenAduatuca", function ()
			civ.ui.text(func.splitlines("Sabinus and Cotta arrive in Aduatuca, intent on building a fort and establishing winter quarters for their legions.  Little do they know, whispers of rebellion are in the air! They are soon surrounded by an enormous Eburones Army! Desperate, the Romans form an 'orbis,' a defensive, circular position, and brace for the onslaught!"))
					
			civlua.createUnit(eburonesSwordsmen, belgaeTribe, {{179,29,0},{178,30,0},{184,30,0},{184,28,0}}, {count=4, randomize=true, veteran=true})
			civlua.createUnit(eburonesSpearmen, belgaeTribe, {{183,27,0},{184,26,0},{181,25,0},{184,32,0}}, {count=6, randomize=true, veteran=true})
			civlua.createUnit(eburonesNobles, belgaeTribe, {{177,33,0},{178,34,0},{179,27,0},{179,35,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(eburonesCavalry, belgaeTribe, {{177,35,0},{175,31,0},{177,27,0},{175,35,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(eburonesSwordsmen, belgaeTribe, {{179,29,0},{178,30,0},{184,30,0},{184,28,0}}, {count=4, randomize=true, veteran=true})
			civlua.createUnit(eburonesSpearmen, belgaeTribe, {{183,27,0},{184,26,0},{181,25,0},{184,32,0}}, {count=4, randomize=true, veteran=true})
			civlua.createUnit(eburonesNobles, belgaeTribe, {{177,33,0},{178,34,0},{179,27,0},{179,35,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(eburonesCavalry, belgaeTribe, {{177,35,0},{175,31,0},{177,27,0},{175,35,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(eburonesSwordsmen, belgaeTribe, {{179,29,0},{178,30,0},{184,30,0},{184,28,0}}, {count=7, randomize=true, veteran=true})
			civlua.createUnit(eburonesSpearmen, belgaeTribe, {{183,27,0},{184,26,0},{181,25,0},{184,32,0}}, {count=5, randomize=true, veteran=true})
			civlua.createUnit(eburonesNobles, belgaeTribe, {{177,33,0},{178,34,0},{179,27,0},{179,35,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(eburonesCavalry, belgaeTribe, {{177,35,0},{175,31,0},{177,27,0},{175,35,0}}, {count=2, randomize=true, veteran=true})
			
		
		end)

	end

	if city.id == cityID["Juliobona"] and conqueror.id == romanTribe.id then
		civ.ui.text(func.splitlines("The Romans sack Juliobona! Desperate Gallic Townfolk flee into the countryside!"))
		state.citiesTaken.others.juliobonaTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{94,40,0},{95,41,0}}, {count=1, randomize=false, veteran=false})
	end
	
	if city.id == cityID["Avaricum"] and conqueror.id == romanTribe.id then
		state.citiesTaken.others.avaricumTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{94,40,0},{95,41,0}}, {count=1, randomize=false, veteran=false})
	
		justOnce("takenAvaricum", function ()
			civ.ui.text(func.splitlines("The siege of Avaricum ends after 27 days! The garrison attemps to flee across the marsh to join the main Gallic forces.  Meanwhile, Caesar orders the massacre of all the inhabitants, including the women and children.  This so repulses the Aedui that many of them turn on Rome!"))
					
			civlua.createUnit(arverniSwordsmen, averniTribe, {{128,72,0},{128,70,0},{132,72,0},{133,73,0}}, {count=3, randomize=true, veteran=true})
			civlua.createUnit(arverniSpearmen, averniTribe, {{129,65,0},{128,66,0},{128,72,0},{128,70,0}}, {count=3, randomize=true, veteran=true})
			civlua.createUnit(arverniNobles, averniTribe, {{128,72,0},{128,70,0},{132,72,0},{133,73,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(arverniCavalry, averniTribe, {{129,65,0},{128,66,0},{128,72,0},{128,70,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(arverniArchers, averniTribe, {{128,72,0},{128,70,0},{132,72,0},{133,73,0}}, {count=4, randomize=true, veteran=true})
			civlua.createUnit(aeudiAllies, averniTribe, {{161,71,0},{164,66,0},{166,68,0},{168,70,0}}, {count=4, randomize=true, veteran=true})
			civlua.createUnit(aeudiAllies, averniTribe, {{165,71,0},{163,71,0},{165,67,0},{166,72,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(aeudiAllies, averniTribe, {{157,75,0},{157,73,0},{159,73,0},{166,68,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(aeudiAllies, averniTribe, {{161,71,0},{164,66,0},{166,68,0},{168,70,0}}, {count=7, randomize=true, veteran=true})
			civlua.createUnit(aeudiAllies, averniTribe, {{165,71,0},{163,71,0},{165,67,0},{166,72,0}}, {count=5, randomize=true, veteran=true})
			civlua.createUnit(aeudiAllies, averniTribe, {{157,75,0},{157,73,0},{159,73,0},{166,68,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(aeudiAllies, averniTribe, {{161,71,0},{164,66,0},{166,68,0},{168,70,0}}, {count=2, randomize=true, veteran=true})
			
		
		end)

	end

	if city.id == cityID["Gergovia"] and conqueror.id == romanTribe.id then
		state.citiesTaken.others.gergoviaTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{105,85,0},{105,87,0}}, {count=1, randomize=false, veteran=false})
	
		justOnce("takenGergovia", function ()
			civ.ui.text(func.splitlines("A massive Gallic army has arrived outside Gergovia.  To our dismay, we see that it includes several of our Aedui 'allies,' lead by the treacherous Convictolanis!"))
					
			civlua.createUnit(arverniSwordsmen, averniTribe, {{105,85,0},{105,87,0},{106,80,0},{110,80,0}}, {count=6, randomize=true, veteran=true})
			civlua.createUnit(arverniSpearmen, averniTribe, {{111,79,0},{113,83,0},{109,77,0},{108,86,0}}, {count=6, randomize=true, veteran=true})
			civlua.createUnit(arverniNobles, averniTribe, {{108,88,0},{106,86,0},{109,75,0},{110,76,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(arverniCavalry, averniTribe, {{105,85,0},{105,87,0},{106,80,0},{110,80,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(arverniArchers, averniTribe, {{111,79,0},{113,83,0},{109,77,0},{108,86,0}}, {count=4, randomize=true, veteran=true})
			civlua.createUnit(aeudiAllies, averniTribe, {{108,88,0},{106,86,0},{109,75,0},{110,76,0}}, {count=4, randomize=true, veteran=true})
			civlua.createUnit(aeudiAllies, averniTribe, {{105,85,0},{105,87,0},{106,80,0},{110,80,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(aeudiAllies, averniTribe, {{111,79,0},{113,83,0},{109,77,0},{108,86,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(aeudiAllies, averniTribe, {{108,88,0},{106,86,0},{109,75,0},{110,76,0}}, {count=7, randomize=true, veteran=true})
			civlua.createUnit(aeudiAllies, averniTribe, {{105,85,0},{105,87,0},{106,80,0},{110,80,0}}, {count=5, randomize=true, veteran=true})
			civlua.createUnit(aeudiAllies, averniTribe, {{111,79,0},{113,83,0},{109,77,0},{108,86,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(aeudiAllies, averniTribe, {{108,88,0},{106,86,0},{109,75,0},{110,76,0}}, {count=2, randomize=true, veteran=true})
			
		
		end)

	end

	if city.id == cityID["Lutetia"] and conqueror.id == romanTribe.id then
		state.citiesTaken.others.lutetiaTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{130,46,0},{128,46,0}}, {count=1, randomize=false, veteran=false})
	
		justOnce("takenLutetia", function ()
			civ.ui.text(func.splitlines("Two large Gallic armies approaching form the north and south have trapped our Legions at Lutetia! Completely surrounded, we prepare to fight!"))
					
			civlua.createUnit(arverniSwordsmen, averniTribe, {{130,46,0},{128,46,0},{132,46,0},{134,46,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(arverniSpearmen, averniTribe, {{130,54,0},{132,54,0},{133,53,0},{134,52,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(arverniNobles, averniTribe, {{130,46,0},{128,46,0},{132,46,0},{134,46,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(arverniCavalry, averniTribe, {{130,54,0},{132,54,0},{133,53,0},{134,52,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(arverniArchers, averniTribe, {{130,46,0},{128,46,0},{132,46,0},{134,46,0}}, {count=4, randomize=true, veteran=true})
			civlua.createUnit(arverniSwordsmen, averniTribe, {{130,54,0},{132,54,0},{133,53,0},{134,52,0}}, {count=4, randomize=true, veteran=true})
					
		
		end)

	end
	
	if city.id == cityID["Gergobina"] and conqueror.id == romanTribe.id then
		state.citiesTaken.others.gergobinaTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{130,46,0},{128,46,0}}, {count=1, randomize=false, veteran=false})
	
		justOnce("takenGergobina", function ()
			civ.ui.text(func.splitlines("Our legions march into Gergobina to the relief of our Gallic Allies.  Several units of cavalry join our cause."))
					
			civlua.createUnit(gallicCav, romanTribe, {{136,80,0}}, {count=4, randomize=false, veteran=true})		
		end)

	end


	if city.id == cityID["Augustodorum"] and conqueror.id == romanTribe.id then
		civ.ui.text(func.splitlines("The Romans sack Augustodorum! Desperate Gallic Townfolk flee into the countryside!"))
		state.citiesTaken.others.augustodorumTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{81,39,0},{83,43,0}}, {count=1, randomize=false, veteran=false})
	end
	
	if city.id == cityID["Bratuspantium"] and conqueror.id == romanTribe.id then
		civ.ui.text(func.splitlines("The capture of Bratuspantium opens the way to further campaigns to the west, and the lands of the Veneti."))
		state.citiesTaken.belgae.bratuspantiumTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{124,40,0},{122,42,0}}, {count=1, randomize=false, veteran=false})
	end
	
	if city.id == cityID["Bibrax"] and conqueror.id == romanTribe.id then
		state.citiesTaken.belgae.bibraxTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{164,42,0},{165,45,0}}, {count=1, randomize=false, veteran=false})
		
		justOnce("takenBibrax", function ()
			civ.ui.text(func.splitlines("Following up on the Remi's cry for help, the Romans march into Bibrax, and into battle against the Remi's oppressors!"))
					
			civlua.createUnit(belgaeWarriors, belgaeTribe, {{162,42,0},{161,43,0},{159,43,0},{165,45,0}}, {count=3, randomize=true, veteran=true})
			civlua.createUnit(belgaeWarriors, belgaeTribe, {{165,47,0},{165,43,0},{165,41,0},{167,43,0}}, {count=3, randomize=true, veteran=true})
			civlua.createUnit(belgaeNobles, belgaeTribe, {{166,48,0},{162,40,0},{165,39,0},{163,41,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(nerviiWarriors, belgaeTribe, {{162,42,0},{161,43,0},{159,43,0},{165,45,0}}, {count=6, randomize=true, veteran=true})
			civlua.createUnit(nerviiWarriors, belgaeTribe, {{165,47,0},{165,43,0},{165,41,0},{167,43,0}}, {count=6, randomize=true, veteran=true})
			civlua.createUnit(nerviiWarriors, belgaeTribe, {{162,42,0},{161,43,0},{159,43,0},{165,45,0}}, {count=6, randomize=true, veteran=true})
			civlua.createUnit(eburonesCavalry, belgaeTribe, {{165,47,0},{165,43,0},{165,41,0},{167,43,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(eburonesCavalry, belgaeTribe, {{166,48,0},{162,40,0},{165,39,0},{163,41,0}}, {count=2, randomize=true, veteran=true})
			
		
		end)

	end
	
	if city.id == cityID["Aisne"] and conqueror.id == romanTribe.id then
		civ.ui.text(func.splitlines("A Belgic tribe, the Remi, has appealed to Caesar for protection against their warlike neighbors.  To reach their city of Bibrax, we must first cross the Aisne.  A large army of Belgae has formed in an attempt to stop us!"))
		state.citiesTaken.belgae.aisneTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{157,47,0},{155,47,0}}, {count=1, randomize=false, veteran=false})
	
		justOnce("takenAisne", function ()
								
			civlua.createUnit(belgaeWarriors, belgaeTribe, {{157,45,0},{154,46,0},{153,49,0},{160,46,0}}, {count=3, randomize=true, veteran=true})
			civlua.createUnit(belgaeWarriors, belgaeTribe, {{162,46,0},{162,48,0},{160,48,0},{154,48,0}}, {count=3, randomize=true, veteran=true})
			civlua.createUnit(belgaeNobles, belgaeTribe, {{154,50,0},{162,50,0},{157,47,0},{153,53,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(nerviiWarriors, belgaeTribe, {{157,45,0},{154,46,0},{153,49,0},{160,46,0}}, {count=6, randomize=true, veteran=true})
			civlua.createUnit(nerviiWarriors, belgaeTribe, {{162,46,0},{162,48,0},{160,48,0},{154,48,0}}, {count=6, randomize=true, veteran=true})
			civlua.createUnit(nerviiWarriors, belgaeTribe, {{154,50,0},{162,50,0},{157,47,0},{153,53,0}}, {count=6, randomize=true, veteran=true})
			civlua.createUnit(eburonesCavalry, belgaeTribe, {{157,45,0},{154,46,0},{153,49,0},{160,46,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(eburonesCavalry, belgaeTribe, {{166,48,0},{162,40,0},{165,39,0},{163,41,0}}, {count=2, randomize=true, veteran=true})
			
		
		end)

	end
	
	if city.id == cityID["Nervii"] and conqueror.id == romanTribe.id then
		state.citiesTaken.belgae.nerviiTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{157,47,0},{155,47,0}}, {count=1, randomize=false, veteran=false})
	
		justOnce("takenNervii", function ()
			civ.ui.text(func.splitlines("The Nervii are a fierce and proud tribe.  Warriors from across the land assemble to repel the Roman invaders!"))
					
			civlua.createUnit(nerviiWarriors, belgaeTribe, {{170,32,0},{169,31,0},{169,35,0},{171,33,0}}, {count=3, randomize=true, veteran=true})
			civlua.createUnit(nerviiWarriors, belgaeTribe, {{166,30,0},{163,20,0},{168,34,0},{161,29,0}}, {count=3, randomize=true, veteran=true})
			civlua.createUnit(nerviiWarriors, belgaeTribe, {{161,31,0},{163,27,0},{170,34,0},{166,36,0}}, {count=6, randomize=true, veteran=true})
			civlua.createUnit(nerviiWarriors, belgaeTribe, {{164,36,0},{169,35,0},{168,34,0},{170,34,0}}, {count=6, randomize=true, veteran=true})
			civlua.createUnit(nerviiWarriors, belgaeTribe, {{170,32,0},{169,31,0},{169,35,0},{171,33,0}}, {count=6, randomize=true, veteran=true})
			civlua.createUnit(nerviiWarriors, belgaeTribe, {{166,30,0},{163,20,0},{168,34,0},{161,29,0}}, {count=6, randomize=true, veteran=true})
			civlua.createUnit(eburonesCavalry, belgaeTribe, {{161,31,0},{163,27,0},{170,34,0},{166,36,0}}, {count=2, randomize=true, veteran=true})
			civlua.createUnit(eburonesCavalry, belgaeTribe, {{164,36,0},{169,35,0},{168,34,0},{170,34,0}}, {count=2, randomize=true, veteran=true})
			
		
		end)

	end

	if city.id == cityID["Namnetum"] and conqueror.id == romanTribe.id then
		civ.ui.text(func.splitlines("The Romans sack Namnetum! Desperate Gallic Townfolk flee into the countryside!"))
		state.citiesTaken.others.namnetumTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{61,61,0},{61,63,0}}, {count=1, randomize=false, veteran=false})

		justOnce("takenNamnetum", function ()
			civ.ui.text(func.splitlines("The Romans capture the Veneti port of Namnetum.  Caesar quickly orders the construction of a mighty fleet to take on the Veneti's many island fortresses.  It will be necessary to conduct amphibious landings to bring the full brunt of Roman power to bear--a difficult task while the Veneti rule the seas!"))
					
			civlua.createUnit(quinquereme, romanTribe, {{59,61,0}}, {count=2, randomize=false, veteran=false})
			civlua.createUnit(trireme, romanTribe, {{59,61,0}}, {count=6, randomize=false, veteran=false})
			civlua.createUnit(lightShip, venetiiTribe, {{36,60,0}}, {count=2, randomize=false, veteran=true})
			civlua.createUnit(heavyShip, venetiiTribe, {{44,58,0}}, {count=2, randomize=false, veteran=true})
			civlua.createUnit(lightShip, venetiiTribe, {{35,67,0}}, {count=2, randomize=false, veteran=true})
			civlua.createUnit(heavyShip, venetiiTribe, {{46,64,0}}, {count=2, randomize=false, veteran=true})
			civlua.createUnit(lightShip, venetiiTribe, {{44,70,0}}, {count=2, randomize=false, veteran=true})
			civlua.createUnit(heavyShip, venetiiTribe, {{50,60,0}}, {count=2, randomize=false, veteran=true})
			
		
		end)

	end



	if city.id == cityID["Condata"] and city.owner.id == romanTribe.id then
		civ.ui.text(func.splitlines("The Romans sack Condata! Desperate Gallic Townfolk flee into the countryside!"))
		state.citiesTaken.others.condataTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{48,46,0},{47,47,0}}, {count=1, randomize=false, veteran=false})
		
		--g change terrain - allow access to Brittany
  		justOnce("CondataAccessToBrittany", function () 
		--change 49,47,53,47,53,55,49,55 to forest (terrain=3) (from deep forest) with text). 
   		civ.ui.text(func.splitlines("Accepting the inevitability of conquest, some Veneti guide the Romans through the deep forests.  The remote region of Brittany now lies open to the boots of the Roman legionaries!"))
			
		for __,location in ipairs(accessToBrittanyLocations) do
			civ.getTile(location[1], location[2], location[3]).terrainType = 3
  		end

			
		end)

	end
	
	if city.id == cityID["Darioritum"] and conqueror.id == romanTribe.id then
		civ.ui.text(func.splitlines("The Romans sack Darioritum! Desperate Gallic Townfolk flee into the countryside!"))
		state.citiesTaken.others.darioritumTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{42,50,0},{40,50,0}}, {count=1, randomize=false, veteran=false})
	end
	
	if city.id == cityID["Gesoscribate"] and conqueror.id == romanTribe.id then
		civ.ui.text(func.splitlines("The Romans sack Gesoscribate! Desperate Gallic Townfolk flee into the countryside!"))
		state.citiesTaken.others.gesoscribateTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{17,39,0},{18,40,0}}, {count=1, randomize=false, veteran=false})
	end
	
	if city.id == cityID["Isle Fort"] and conqueror.id == romanTribe.id then
		state.citiesTaken.others.isleFortTaken=true
	end
	
	if city.id == cityID["Cenomani"] and conqueror.id == romanTribe.id then
		civ.ui.text(func.splitlines("The Romans ravage the territory of the Cenomani! Desperate Gallic Townfolk flee into the countryside!"))
		state.citiesTaken.others.cenomaniTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{74,60,0},{76,58,0}}, {count=1, randomize=false, veteran=false})
	end
	
	if city.id == cityID["Aulerci"] and conqueror.id == romanTribe.id then
		civ.ui.text(func.splitlines("The Romans invade Aulerci territory! Desperate Gallic Townfolk flee into the countryside!"))
		state.citiesTaken.others.aulerciTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{73,51,0},{72,50,0}}, {count=1, randomize=false, veteran=false})
	end
	
	if city.id == cityID["Stronghold"] and conqueror.id == romanTribe.id then
		state.citiesTaken.others.strongholdTaken=true
	end
	
	if city.id == cityID["Fortress"] and conqueror.id == romanTribe.id then
		state.citiesTaken.others.fortressTaken=true
	end
	
	if city.id == cityID["Limonum"] and conqueror.id == romanTribe.id then
		civ.ui.text(func.splitlines("The Romans sack Limonum! Desperate Gallic Townfolk flee into the countryside!"))
		state.citiesTaken.others.limonumTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{72,68,0},{72,70,0}}, {count=1, randomize=false, veteran=false})
	end
	
	if city.id == cityID["Santonum"] and conqueror.id == romanTribe.id then
		civ.ui.text(func.splitlines("The Romans move against the Aquitani.  This will be hard fighting in difficult country, but necessary to subdue the rest of Gaul!"))
		state.citiesTaken.others.santonumTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{61,71,0},{64,72,0}}, {count=1, randomize=false, veteran=false})
	end
	
	if city.id == cityID["Burgidala"] and conqueror.id == romanTribe.id then
		civ.ui.text(func.splitlines("The Romans sack Burgidala! Desperate Gallic Townfolk flee into the countryside!"))
		state.citiesTaken.others.burgidalaTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{57,89,0},{56,90,0}}, {count=1, randomize=false, veteran=false})
	end
	
	if city.id == cityID["Tarusates"] and conqueror.id == romanTribe.id then
		state.citiesTaken.others.tarusatesTaken=true
	
		justOnce("takenTarusates", function ()
			civ.ui.text(func.splitlines("The Roman campaign in south-west Gaul continues, with heavy fighting against the Tarusates."))
					
			civlua.createUnit(tarusatesArmy, aquitaniiTribe, {{72,104,0}, {75,103,0}, {78,106,0}}, {count=4, randomize=true, veteran=true})
			civlua.createUnit(tarusatesArmy, aquitaniiTribe, {{78,108,0}, {74,112,0}, {71,107,0}}, {count=4, randomize=true, veteran=false})
			civlua.createUnit(tarusatesArmy, aquitaniiTribe, {{72,104,0}, {75,103,0}, {78,106,0}}, {count=4, randomize=true, veteran=true})
			civlua.createUnit(tarusatesArmy, aquitaniiTribe, {{78,108,0}, {74,112,0}, {71,107,0}}, {count=4, randomize=true, veteran=false})
						
		
		end)

	end
	
	if city.id == cityID["Sotiates"] and conqueror.id == romanTribe.id then
		civ.ui.text(func.splitlines("The Romans invade the lands of the Sotiates! Desperate Gallic Townfolk flee into the countryside!"))
		state.citiesTaken.others.sotiatesTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{59,109,0},{61,109,0}}, {count=1, randomize=false, veteran=false})
	
		justOnce("takenTarusates", function ()
			civ.ui.text(func.splitlines("Having lured the Romans into a narrow valley, the Sotiates spring their trap!"))
					
			civlua.createUnit(sotiates, aquitaniiTribe, {{59,103,0}, {58,104,0}}, {count=6, randomize=true, veteran=true})
			civlua.createUnit(sotiates, aquitaniiTribe, {{60,106,0}, {57,105,0}}, {count=6, randomize=true, veteran=false})
			civlua.createUnit(sotiates, aquitaniiTribe, {{59,107,0}, {56,106,0}}, {count=6, randomize=true, veteran=true})
									
		
		end)

	end

	if city.id == cityID["Lapurdum"] and conqueror.id == romanTribe.id then
		civ.ui.text(func.splitlines("The Romans sack Lapurdum! Desperate Gallic Townfolk flee into the countryside!"))
		state.citiesTaken.others.lapurdumTaken=true
		civlua.createUnit(gallicTownfolk, defender, {{33,103,0},{36,104,0}}, {count=1, randomize=false, veteran=false})
	end
	
end)
------------------------------------------------------------------------------------------------------------------------------------------------
-- onCityProduction ----------------------------------------------------------------------------------------------------------------------------

civ.scen.onCityProduction(function (city, prod)
end)

------------------------------------------------------------------------------------------------------------------------------------------------

--g limitations in production

--g define tables with possible restrictions
--g		unit= ... unittype to be resticted
--g		conditionMet= ... a function depending on the city and the state/persistent variables which returns a boolean. If true then the item is displayed in the list of buildable items.
local buildRestrictionsUnits={
   ["romanCavalry"] = {unit=civ.getUnitType(72), conditionMet=function (city, state) if civ.hasImprovement(city, civ.getImprovement(18)) then return defaultBuildFunction(city,item) else return false end end}
   ,["scorpioArtillery"] = {unit=civ.getUnitType(70), conditionMet=function (city, state) if civ.hasImprovement(city, civ.getImprovement(17)) then return defaultBuildFunction(city,item) else return false end end}
   ,["onagerArtillery"] = {unit=civ.getUnitType(71), conditionMet=function (city, state) if civ.hasImprovement(city, civ.getImprovement(17)) then return defaultBuildFunction(city,item) else return false end end}
}

local buildRestrictionsImprovements={
   ["TestImp"] = {improvement=civ.getImprovement(26), conditionMet=function (city, state) if state.thisCanBeBuilt==true then return true else return false end end}
}

local buildRestrictionsWonders={
   ["TestWonder"] = {wonder=civ.getWonder(0), conditionMet=function (city, state) if state.thisCanBeBuilt==true then return true else return false end end}
}


civ.scen.onCanBuild(function (defaultBuildFunction, city, item)

	local separateCondition=nil
   
	--g if the item is an unit, and a table of possible restrictions to building units has been defined / is not nil, then loop the table entries
	if civ.isUnitType(item) and buildRestrictionsUnits ~= nil then
       for _,restrictedUnit in pairs(buildRestrictionsUnits) do
           --[[justOnce("DebugPrint", function ()
               civ.ui.text(func.splitlines(tostring(restrictedUnit.unit.id)))
           end)--]]
           if item.id==restrictedUnit.unit.id then
               separateCondition=restrictedUnit.conditionMet(city,state)
           end
       end
	end
   
	--g if the item is an improvement, and a table of possible restrictions to building improvements has been defined / is not nil, then loop the table entries
	if civ.isImprovement(item) and buildRestrictionsImprovements ~= nil then
       for _,restrictedImprovement in pairs(buildRestrictionsImprovements) do
           if item.id==restrictedImprovement.improvement.id then
               separateCondition=restrictedImprovement.conditionMet(city,state)
           end
       end
	end
   
	--g if the item is a wonder, and a table of possible restrictions to building wonders has been defined / is not nil, then loop the table entries
	if civ.isWonder(item) and buildRestrictionsWonders ~= nil then
       for _,restrictedWonder in pairs(buildRestrictionsWonders) do
           if item.id==restrictedWonder.wonder.id then
               separateCondition=restrictedWonder.conditionMet(city,state)
           end
       end
	end
   
	if separateCondition==nil then
       return defaultBuildFunction(city,item)
	else
       return separateCondition
	end

end)




------------------------------------------------------------------------------------------------------------------------------------------------

-- `onNegotiation` runs not only when diplomatic negotiations occur between tribes, but also when opening the Foreign Minister dialog. Return `true` to allow the two tribes to negotiate, `false` to disallow.
--g 'Caesars Gallic Wars' does not have diplomacy :)
civ.scen.onNegotiation(function (talker, listener)
  return false
end)

--g 'onSchism' - disallow all schisms
civ.scen.onSchism(function (tribe)
  return false
end)


------------------------------------------------------------------------------------------------------------------------------------------------
-- `onLoad` is responsible for restoring scenario state from a string. `onSave` is responsible for returning the state as a string. The implementations given here should suffice as a basis for most scenarios.
civ.scen.onLoad(function (buffer) 
	state = civlua.unserialize(buffer) 
	--g initalize all variables/flags in state so they are never nil
	state.caesarKilled=state.caesarKilled or 0
	state.genavamTaken=state.genavamTaken or 0
	state.germanicInvasion=state.germanicInvasion or 0
	state.ariovistusDefeated=state.ariovistusDefeated or 0
	state.ambiorixUprising=state.ambiorixUprising or 0
	state.vercingetorixUprising=state.vercingetorixUprising or 0
	state.aeudiRecruitment=state.aeudiRecruitment or 1
	state.bataviRecruitment=state.bataviRecruitment or 1
	state.germanRecruitment=state.germanRecruitment or 1
	state.winterSeason=state.winterSeason or 0 --g equivalent: Roman Flag 20 in events.txt
	state.belgaeMobilization=state.belgaeMobilization or 0 --g equivalent: Belgae Flag 20 in events.txt
	
	state.citiesTaken= state.citiesTaken or {belgae={}, others={} }

	state.legioDestroyed = state.legioDestroyed or {}

	setTerrainGraphicsAndRules(state.winterSeason)

end)
civ.scen.onSave(function () return civlua.serialize(state) end)
------------------------------------------------------------------------------------------------------------------------------------------------



